---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:decreto.legislativo:2009;150
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20091031&codiceRedaz=009G0164&dataVigenza=20251104
dataGU: 20091031
codiceRedaz: 009G0164
dataVigenza: 20251104
---

# Attuazione della legge 4 marzo 2009, n. 15, in materia di
ottimizzazione della produttivita' del lavoro pubblico e di
efficienza e trasparenza delle pubbliche amministrazioni. (09G0164)

IL PRESIDENTE DELLA REPUBBLICA

Visti gli articoli 76, 87, 92, 95 e 117 della Costituzione;

Vista la legge 4 marzo 2009, n. 15, recante delega al Governo finalizzata all'ottimizzazione della produttivita' del lavoro pubblico e alla efficienza e trasparenza delle pubbliche amministrazioni, nonche' disposizioni integrative delle funzioni attribuite al Consiglio nazionale dell'economia e del lavoro e alla Corte dei conti;

Visto il decreto legislativo 30 luglio 1999, n. 286, recante riordino e potenziamento dei meccanismi e strumenti di monitoraggio e valutazione dei costi, dei rendimenti e dei risultati dell'attivita' svolta dalle amministrazioni pubbliche, a norma dell'articolo 11 della legge 15 marzo 1997, n. 59, e successive modificazioni;

Visto il decreto legislativo 30 luglio 1999, n. 300, recante riforma dell'organizzazione del Governo, a norma dell'articolo 11 della legge 15 marzo 1997, n. 59, e successive modificazioni;

Visto il decreto legislativo 30 luglio 1999, n. 303, recante ordinamento della Presidenza del Consiglio dei Ministri, a norma dell'articolo 11 della legge 15 marzo 1997, n. 59, e successive modificazioni;

Visto il decreto legislativo 30 marzo 2001, n. 165, recante: norme generali sull'ordinamento del lavoro alle dipendenze delle amministrazioni pubbliche, e successive modificazioni;

Visto il decreto legislativo 30 giugno 2003, n.196, recante codice in materia di protezione dei dati personali, e successive modificazioni;

Visto il decreto legislativo 7 marzo 2005, n. 82, recante codice dell'amministrazione digitale, e successive modificazioni;

Visto il decreto legislativo 11 aprile 2006, n. 198, recante codice delle pari opportunita' tra uomo e donna, a norma dell'articolo 6 della legge 28 novembre 2005, n. 246;

Vista la direttiva dei Ministri per le riforme e le innovazioni nella pubblica amministrazione e per le pari opportunita' del 23 maggio 2007, pubblicata nella Gazzetta Ufficiale n.173 del 27 luglio 2007, recante misure per attuare la parita' e le pari opportunita' tra uomini e donne nelle amministrazioni pubbliche;

Visto il decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n.133;

Vista la preliminare deliberazione del Consiglio dei Ministri, adottata nella riunione dell'8 maggio 2009;

Acquisita l'intesa della Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, relativamente all'attuazione delle disposizioni di cui agli articoli 3, comma 2, lettera a), 4, 5 e 6, della citata legge n. 15 del 2009, salvo che sull'articolo 60, comma 1, lettera b), nonche' il parere della medesima Conferenza relativamente all'attuazione delle restanti disposizioni della medesima legge n. 15 del 2009 nella seduta del 29 luglio 2009;

Rilevato, in ordine al predetto articolo 60, comma 1, lettera b), del decreto, che gli enti territoriali chiedevano di prevedere che la determinazione delle risorse per gli incrementi retributivi destinati al rinnovo dei contratti collettivi nazionali delle amministrazioni regionali, locali e degli enti del Servizio sanitario nazionale avvenga previa concertazione con le proprie rappresentanze;

Acquisiti i pareri delle competenti Commissioni parlamentari della Camera dei deputati e del Senato della Repubblica;

Vista la deliberazione del Consiglio dei Ministri, adottata nella riunione del 9 ottobre 2009;

Sulla proposta del Ministro per la pubblica amministrazione e l'innovazione, di concerto con il Ministro dell'economia e delle finanze;

Emana il seguente decreto legislativo:

## PRINCIPI GENERALI

### Art. 1. - Oggetto e finalita'

1. In attuazione degli articoli da 2 a 7 della legge 4 marzo 2009, n. 15, le disposizioni del presente decreto recano una riforma organica della disciplina del rapporto di lavoro dei dipendenti delle amministrazioni pubbliche, di cui all'articolo 2, comma 2, del decreto legislativo 30 marzo 2001, n. 165, intervenendo in particolare in materia di contrattazione collettiva, di valutazione delle strutture e del personale delle amministrazioni pubbliche, di valorizzazione del merito, di promozione delle pari opportunita', di dirigenza pubblica e di responsabilita' disciplinare. Fermo quanto previsto dall'articolo 3 del decreto legislativo 30 marzo 2001, n. 165, recano altresi' norme di raccordo per armonizzare con la nuova disciplina i procedimenti negoziali, di contrattazione e di concertazione di cui all'articolo 112 del decreto del Presidente della Repubblica 5 gennaio 1967, n. 18, e ai decreti legislativi 12 maggio 1995, n. 195, 19 maggio 2000, n. 139, 13 ottobre 2005, n. 217, e 15 febbraio 2006, n. 63.

2. Le disposizioni del presente decreto assicurano una migliore organizzazione del lavoro, il rispetto degli ambiti riservati rispettivamente alla legge e alla contrattazione collettiva, elevati standard qualitativi ed economici delle funzioni e dei servizi, l'incentivazione della qualita' della prestazione lavorativa, la selettivita' e la concorsualita' nelle progressioni di carriera, il riconoscimento di meriti e demeriti, la selettivita' e la valorizzazione delle capacita' e dei risultati ai fini degli incarichi dirigenziali, il rafforzamento dell'autonomia, dei poteri e della responsabilita' della dirigenza, l'incremento dell'efficienza del lavoro pubblico ed il contrasto alla scarsa produttivita' e all'assenteismo, nonche' la trasparenza dell'operato delle amministrazioni pubbliche anche a garanzia della legalita'.

## MISURAZIONE, VALUTAZIONE E TRASPARENZA DELLA PERFORMANCE CAPO I Disposizioni generali

### Art. 2. - Oggetto e finalita'

1. Le disposizioni contenute nel presente Titolo disciplinano il sistema di valutazione delle strutture e dei dipendenti delle amministrazioni pubbliche il cui rapporto di lavoro e' disciplinato dall'articolo 2, comma 2, del decreto legislativo 30 marzo 2001, n. 165, al fine di assicurare elevati standard qualitativi ed economici del servizio tramite la valorizzazione dei risultati e della performance organizzativa e individuale.

### Art. 3. - Principi generali

1. La misurazione e la valutazione della performance sono volte al miglioramento della qualita' dei servizi offerti dalle amministrazioni pubbliche, nonche' alla crescita delle competenze professionali, attraverso la valorizzazione del merito e l'erogazione dei premi per i risultati perseguiti dai singoli e dalle unita' organizzative in un quadro di pari opportunita' di diritti e doveri, trasparenza dei risultati delle amministrazioni pubbliche e delle risorse impiegate per il loro perseguimento.

2. Ogni amministrazione pubblica e' tenuta a misurare ed a valutare la performance con riferimento all'amministrazione nel suo complesso, alle unita' organizzative o aree di responsabilita' in cui si articola e ai singoli dipendenti, secondo le modalita' indicate nel presente Titolo e gli indirizzi impartiti dal Dipartimento della funzione pubblica ai sensi dell'articolo 19 del decreto-legge 24 giugno 2014, n. 90, convertito, con modificazioni, dalla legge 11 agosto 2014, n. 114.

3. Le amministrazioni pubbliche adottano modalita' e strumenti di comunicazione che garantiscono la massima trasparenza delle informazioni concernenti le misurazioni e le valutazioni della performance.

4. Le amministrazioni pubbliche adottano metodi e strumenti idonei a misurare, valutare e premiare la performance individuale e quella organizzativa, secondo criteri strettamente connessi al soddisfacimento dell'interesse del destinatario dei servizi e degli interventi.

5. Il rispetto delle disposizioni del presente Titolo e' condizione necessaria per l'erogazione di premi e componenti del trattamento retributivo legati alla performance e rileva ai fini del riconoscimento delle progressioni economiche, dell'attribuzione di incarichi di responsabilita' al personale, nonche' del conferimento degli incarichi dirigenziali. ((4-bis. Nel valutare la performance individuale ed organizzativa di cui al comma 4 si tiene conto del raggiungimento o meno degli obiettivi per l'effettiva inclusione sociale e la possibilita' di accesso alle persone con disabilita' di cui all'articolo 5, comma 2-bis, anche ai fini dell'applicazione dei commi 5 e 5-bis del presente articolo.))

5-bis. La valutazione negativa, come disciplinata nell'ambito del sistema di misurazione e valutazione della performance, rileva ai fini dell'accertamento della responsabilita' dirigenziale e ai fini dell'irrogazione del licenziamento disciplinare ai sensi dell'articolo 55-quater, comma 1, lettera f-quinquies), del decreto legislativo 30 marzo 2001, n. 165, ove resa a tali fini specifici nel rispetto delle disposizioni del presente decreto.

6. Fermo quanto previsto dall'articolo 13, dall'applicazione delle disposizioni del presente Titolo non devono derivare nuovi o maggiori oneri per la finanza pubblica. Le amministrazioni interessate utilizzano a tale fine le risorse umane, finanziarie e strumentali disponibili a legislazione vigente.

## Il ciclo di gestione della performance

### Art. 4. - Ciclo di gestione della performance

1. Ai fini dell'attuazione dei principi generali di cui all'articolo 3, le amministrazioni pubbliche sviluppano, in maniera coerente con i contenuti e con il ciclo della programmazione finanziaria e del bilancio, il ciclo di gestione della performance.

2. Il ciclo di gestione della performance si articola nelle seguenti fasi:

- a) definizione e assegnazione degli obiettivi che si intendono raggiungere, dei valori attesi di risultato e dei rispettivi indicatori ((, tenendo conto anche dei risultati conseguiti nell'anno precedente, come documentati e validati nella relazione annuale sulla performance di cui all'articolo 10));
- b) collegamento tra gli obiettivi e l'allocazione delle risorse;
- c) monitoraggio in corso di esercizio e attivazione di eventuali interventi correttivi;
- d) misurazione e valutazione della performance, organizzativa e individuale;
- e) utilizzo dei sistemi premianti, secondo criteri di valorizzazione del merito;
- f) rendicontazione dei risultati agli organi di indirizzo politico-amministrativo, ai vertici delle amministrazioni, nonche' ai competenti organi ((di controllo interni ed)) esterni, ai cittadini, ai soggetti interessati, agli utenti e ai destinatari dei servizi. ((10))

--------------- AGGIORNAMENTO (10) Il D.Lgs. 25 maggio 2017, n. 74 ha disposto (con l'art. 2, comma 1, lettera b)) che al comma 2, lettera f), del presente articolo dopo la parola: «organi» sono inserite le seguenti: «di controllo interni ed».

### Art. 5. - Obiettivi e indicatori

01. Gli obiettivi si articolano in:

- a) obiettivi generali, che identificano, in coerenza con le priorita' delle politiche pubbliche nazionali nel quadro del programma di Governo e con gli eventuali indirizzi adottati dal Presidente del Consiglio dei ministri ai sensi dell'articolo 8 del decreto legislativo 30 luglio 1999, n. 286, le priorita' strategiche delle pubbliche amministrazioni in relazione alle attivita' e ai servizi erogati, anche tenendo conto del comparto di contrattazione di appartenenza e in relazione anche al livello e alla qualita' dei servizi da garantire ai cittadini;
- b) obiettivi specifici di ogni pubblica amministrazione, individuati, in coerenza con la direttiva annuale adottata ai sensi dell'articolo 8 del decreto legislativo 30 luglio 1999, n. 286, nel Piano della performance di cui all'articolo 10.

1. Gli obiettivi di cui al comma 01, lettera a), sono determinati con apposite linee guida adottate su base triennale con decreto del Presidente del Consiglio dei ministri. Per gli enti territoriali, il decreto di cui al primo periodo e' adottato previa intesa in sede di Conferenza unificata di cui all'articolo 8 della legge 5 giugno 2003, n. 131. Gli obiettivi di cui al comma 01, lettera b), sono programmati, in coerenza con gli obiettivi generali, su base triennale e definiti, prima dell'inizio del rispettivo esercizio, dagli organi di indirizzo politico-amministrativo, sentiti i vertici dell'amministrazione che a loro volta consultano i dirigenti o i responsabili delle unita' organizzative. Gli obiettivi sono definiti in coerenza con gli obiettivi di bilancio indicati nei documenti programmatici di cui alla legge 31 dicembre 2009, n. 196, e di cui alla normativa economica e finanziaria applicabile alle regioni e agli enti locali e il loro conseguimento costituisce condizione per l'erogazione degli incentivi previsti dalla contrattazione integrativa. Nelle more dell'adozione delle linee guida di determinazione degli obiettivi generali, ogni pubblica amministrazione programma e definisce i propri obiettivi, secondo i tempi stabiliti per l'adozione del Piano di cui all'articolo 10, salvo procedere successivamente al loro aggiornamento.

1-bis. Nel caso di gestione associata di funzioni da parte degli enti locali, su base volontaria ovvero obbligatoria ai sensi dell'articolo 14 del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122, gli obiettivi specifici relativi all'espletamento di tali funzioni sono definiti unitariamente.

1-ter. Nel caso di differimento del termine di adozione del bilancio di previsione degli enti territoriali, devono essere comunque definiti obiettivi specifici per consentire la continuita' dell'azione amministrativa.

2. Gli obiettivi sono:

- a) rilevanti e pertinenti rispetto ai bisogni della collettivita', alla missione istituzionale, alle priorita' politiche ed alle strategie dell'amministrazione;
- b) specifici e misurabili in termini concreti e chiari;
- c) tali da determinare un significativo miglioramento della qualita' dei servizi erogati e degli interventi;
- d) riferibili ad un arco temporale determinato, di norma corrispondente ad un anno;
- e) commisurati ai valori di riferimento derivanti da standard definiti a livello nazionale e internazionale, nonche' da comparazioni con amministrazioni omologhe;
- f) confrontabili con le tendenze della produttivita' dell'amministrazione con riferimento, ove possibile, almeno al triennio precedente;
- g) correlati alla quantita' e alla qualita' delle risorse disponibili.

((

2-bis. Gli obiettivi, anche nell'ottica di una corretta allocazione delle risorse, assicurano l'effettiva inclusione sociale e le possibilita' di accesso delle persone con disabilita'.

))

### Art. 6. - Monitoraggio della performance

1. ((Gli Organismi indipendenti di valutazione, anche accedendo alle risultanze dei sistemi di controllo strategico e di gestione presenti nell'amministrazione)), verificano l'andamento delle performance rispetto agli obiettivi ((programmati durante il periodo di riferimento e segnalano la necessita' o l'opportunita' di interventi correttivi in corso di esercizio all'organo di indirizzo politico-amministrativo, anche in relazione al verificarsi di eventi imprevedibili tali da alterare l'assetto dell'organizzazione e delle risorse a disposizione dell'amministrazione. Le variazioni, verificatesi durante l'esercizio, degli obiettivi e degli indicatori della performance organizzativa e individuale sono inserite nella relazione sulla performance e vengono valutate dall'OIV ai fini della validazione di cui all'articolo 14, comma 4, lettera c).))

2. ((COMMA ABROGATO DAL D.L. 25 MAGGIO 2017, N. 74)).

### Art. 7. - Sistema di misurazione e valutazione della performance

1. Le amministrazioni pubbliche valutano annualmente la performance organizzativa e individuale. A tale fine adottano ((e aggiornano annualmente, previo parere vincolante dell'Organismo indipendente di valutazione,)) il Sistema di misurazione e valutazione della performance.

2. La funzione di misurazione e valutazione delle performance e' svolta:

- a) dagli Organismi indipendenti di valutazione della performance di cui all'articolo 14, cui compete la misurazione e valutazione della performance di ciascuna struttura amministrativa nel suo complesso, nonche' la proposta di valutazione annuale dei dirigenti di vertice ai sensi del comma 4, lettera e), del medesimo articolo;
- b) dai dirigenti di ciascuna amministrazione, secondo quanto previsto agli articoli 8 e 9;
- c) dai cittadini o dagli altri utenti finali in rapporto alla qualita' dei servizi resi dall'amministrazione, partecipando alla valutazione della performance organizzativa dell'amministrazione, secondo quanto stabilito dagli articoli 8 e 19-bis.

((

2-bis. Il Sistema di misurazione e valutazione della performance, di cui al comma 1, e' adottato in coerenza con gli indirizzi impartiti dal Dipartimento della funzione pubblica ai sensi dell'articolo 3, comma 2, e in esso sono previste, altresi', le procedure di conciliazione, a garanzia dei valutati, relative all'applicazione del sistema di misurazione e valutazione della performance e le modalita' di raccordo e integrazione con i documenti di programmazione finanziaria e di bilancio.

))

3. COMMA ABROGATO DAL D.P.R. 9 MAGGIO 2016, N. 105. (8)

-------------- AGGIORNAMENTO (8) Il D.L. 24 giugno 2014, n. 90 convertito con modificazioni dalla L. 11 agosto 2014, n. 114 ha disposto (con l'art. 19, comma 9) che "Al fine di concentrare l'attivita' dell'Autorita' nazionale anticorruzione sui compiti di trasparenza e di prevenzione della corruzione nelle pubbliche amministrazioni, le funzioni della predetta Autorita' in materia di misurazione e valutazione della performance, di cui agli articoli 7, 8, 9, 10, 12, 13 e 14 del decreto legislativo 27 ottobre 2009, n. 150, sono trasferite al Dipartimento della funzione pubblica della Presidenza del Consiglio dei ministri, a decorrere dalla data di entrata in vigore della legge di conversione del presente decreto".

### Art. 8. - Ambiti di misurazione e valutazione della performance organizzativa

1. Il Sistema di misurazione e valutazione della performance organizzativa concerne: ((a) l'attuazione di politiche e il conseguimento di obiettivi collegati ai bisogni e alle esigenze della collettivita';)); b) l'attuazione di piani e programmi, ovvero la misurazione dell'effettivo grado di attuazione dei medesimi, nel rispetto delle fasi e dei tempi previsti, degli standard qualitativi e quantitativi definiti, del livello previsto di assorbimento delle risorse; c) la rilevazione del grado di soddisfazione dei destinatari delle attivita' e dei servizi anche attraverso modalita' interattive; d) la modernizzazione e il miglioramento qualitativo dell'organizzazione e delle competenze professionali e la capacita' di attuazione di piani e programmi; e) lo sviluppo qualitativo e quantitativo delle relazioni con i cittadini, i soggetti interessati, gli utenti e i destinatari dei servizi, anche attraverso lo sviluppo di forme di partecipazione e collaborazione; f) l'efficienza nell'impiego delle risorse, con particolare riferimento al contenimento ed alla riduzione dei costi, nonche' all'ottimizzazione dei tempi dei procedimenti amministrativi; g) la qualita' e la quantita' delle prestazioni e dei servizi erogati; h) il raggiungimento degli obiettivi di promozione delle pari opportunita'.

((1-bis. Le valutazioni della performance organizzativa sono predisposte sulla base di appositi modelli definiti dal Dipartimento della funzione pubblica, tenendo conto anche delle esperienze di valutazione svolte da agenzie esterne di valutazione, ove previste, e degli esiti del confronto tra i soggetti appartenenti alla rete nazionale per la valutazione delle amministrazioni pubbliche, di cui al decreto emanato in attuazione dell'articolo 19 del decreto-legge n. 90 del 2014, con particolare riguardo all'ambito di cui alla lettera g) del comma 1.))

------------ AGGIORNAMENTO (8) Il D.L. 24 giugno 2014, n. 90 convertito con modificazioni dalla L. 11 agosto 2014, n. 114 ha disposto (con l'art. 19, comma 9) che "Al fine di concentrare l'attivita' dell'Autorita' nazionale anticorruzione sui compiti di trasparenza e di prevenzione della corruzione nelle pubbliche amministrazioni, le funzioni della predetta Autorita' in materia di misurazione e valutazione della performance, di cui agli articoli 7, 8, 9, 10, 12, 13 e 14 del decreto legislativo 27 ottobre 2009, n. 150, sono trasferite al Dipartimento della funzione pubblica della Presidenza del Consiglio dei ministri, a decorrere dalla data di entrata in vigore della legge di conversione del presente decreto".

### Art. 9. - Ambiti di misurazione e valutazione della performance individuale

1. La misurazione e la valutazione della performance individuale dei dirigenti e del personale responsabile di una unita' organizzativa in posizione di autonomia e responsabilita', secondo le modalita' indicate nel sistema di cui all'articolo 7, e' collegata:

- a) agli indicatori di performance relativi all'ambito organizzativo di diretta responsabilita', ai quali e' attribuito un peso prevalente nella valutazione complessiva;
- b) al raggiungimento di specifici obiettivi individuali;
- c) alla qualita' del contributo assicurato alla performance generale della struttura, alle competenze professionali e manageriali dimostrate, nonche' ai comportamenti organizzativi richiesti per il piu' efficace svolgimento delle funzioni assegnate;
- d) alla capacita' di valutazione dei propri collaboratori, dimostrata tramite una significativa differenziazione dei giudizi;
- d-bis) agli indicatori di performance relativi al raggiungimento degli obiettivi derivanti dalla programmazione strategica della piena accessibilita' delle amministrazioni, da parte delle persone con disabilita'.

1-bis. La misurazione e valutazione della performance individuale dei dirigenti titolari degli incarichi di cui all'articolo 19, commi 3 e 4, del decreto legislativo 30 marzo 2001, n. 165, e' collegata altresi' al raggiungimento degli obiettivi individuati nella direttiva generale per l'azione amministrativa e la gestione e nel Piano della performance, nonche' di quelli specifici definiti nel contratto individuale.

2. La misurazione e la valutazione svolte dai dirigenti sulla performance individuale del personale sono effettuate sulla base del sistema di cui all'articolo 7 e collegate:

- a) al raggiungimento di specifici obiettivi di gruppo o individuali;
- b) alla qualita' del contributo assicurato alla performance dell'unita' organizzativa di appartenenza, alle competenze dimostrate ed ai comportamenti professionali e organizzativi.

3. Nella valutazione di performance individuale non sono considerati i periodi di congedo di maternita', di paternita' e parentale. (8)

------------ AGGIORNAMENTO (8) Il D.L. 24 giugno 2014, n. 90 convertito con modificazioni dalla L. 11 agosto 2014, n. 114 ha disposto (con l'art. 19, comma 9) che "Al fine di concentrare l'attivita' dell'Autorita' nazionale anticorruzione sui compiti di trasparenza e di prevenzione della corruzione nelle pubbliche amministrazioni, le funzioni della predetta Autorita' in materia di misurazione e valutazione della performance, di cui agli articoli 7, 8, 9, 10, 12, 13 e 14 del decreto legislativo 27 ottobre 2009, n. 150, sono trasferite al Dipartimento della funzione pubblica della Presidenza del Consiglio dei ministri, a decorrere dalla data di entrata in vigore della legge di conversione del presente decreto".

### Art. 10. - Piano della performance e Relazione sulla performance

1. Al fine di assicurare la qualita', comprensibilita' ed attendibilita' dei documenti di rappresentazione della performance, le amministrazioni pubbliche redigono e pubblicano sul sito istituzionale ogni anno:

- a) entro il 31 gennaio, il Piano della performance, documento programmatico triennale, che e' definito dall'organo di indirizzo politico-amministrativo in collaborazione con i vertici dell'amministrazione e secondo gli indirizzi impartiti dal Dipartimento della funzione pubblica ai sensi dell'articolo 3, comma 2, e che individua gli indirizzi e gli obiettivi strategici ed operativi di cui all'articolo 5, comma 01, lettera b), e definisce, con riferimento agli obiettivi finali ed intermedi ed alle risorse, gli indicatori per la misurazione e la valutazione della performance dell'amministrazione, nonche' gli obiettivi assegnati al personale dirigenziale ed i relativi indicatori; ((12))
- b) entro il 30 giugno, la Relazione annuale sulla performance, che e' approvata dall'organo di indirizzo politico-amministrativo e validata dall'Organismo di valutazione ai sensi dell'articolo 14 e che evidenzia, a consuntivo, con riferimento all'anno precedente, i risultati organizzativi e individuali raggiunti rispetto ai singoli obiettivi programmati ed alle risorse, con rilevazione degli eventuali scostamenti, e il bilancio di genere realizzato.

1-bis. Per gli enti locali, ferme restando le previsioni di cui all'articolo 169, comma 3-bis, del decreto legislativo 18 agosto 2000, n. 267, la Relazione sulla performance di cui al comma 1, lettera b), puo' essere unificata al rendiconto della gestione di cui all'articolo 227 del citato decreto legislativo.

1-ter. Il Piano della performance di cui al comma 1, lettera a), e' predisposto a seguito della presentazione alle Camere del documento di economia e finanza, di cui all'articolo 10 della legge 31 dicembre 2009, n. 196. Il Piano delle performance e' adottato non oltre il termine di cui al comma 1, lettera a), in coerenza con le note integrative al bilancio di previsione di cui all'articolo 21 della legge 31 dicembre 2009, n. 196, o con il piano degli indicatori e dei risultati attesi di bilancio, di cui all'articolo 19 del decreto legislativo 31 maggio 2011, n. 91. ((12))

2. COMMA ABROGATO DAL D.P.R. 9 MAGGIO 2016, N. 105.

3. COMMA ABROGATO DAL D.P.R. 9 MAGGIO 2016, N. 105.

4. COMMA ABROGATO DAL D.P.R. 9 MAGGIO 2016, N. 105.

5. In caso di mancata adozione del Piano della performance e' fatto divieto di erogazione della retribuzione di risultato ai dirigenti che risultano avere concorso alla mancata adozione del Piano, per omissione o inerzia nell'adempimento dei propri compiti, e l'amministrazione non puo' procedere ad assunzioni di personale o al conferimento di incarichi di consulenza o di collaborazione comunque denominati. Nei casi in cui la mancata adozione del Piano o della Relazione sulla performance dipenda da omissione o inerzia dell'organo di indirizzo di cui all'articolo 12, comma 1, lettera c), l'erogazione dei trattamenti e delle premialita' di cui al Titolo III e' fonte di responsabilita' amministrativa del titolare dell'organo che ne ha dato disposizione e che ha concorso alla mancata adozione del Piano, ai sensi del periodo precedente. In caso di ritardo nell'adozione del Piano o della Relazione sulla performance, l'amministrazione comunica tempestivamente le ragioni del mancato rispetto dei termini al Dipartimento della funzione pubblica. (8)

-------------- AGGIORNAMENTO (8) Il D.L. 24 giugno 2014, n. 90 convertito con modificazioni dalla L. 11 agosto 2014, n. 114 ha disposto (con l'art. 19, comma 9) che "Al fine di concentrare l'attivita' dell'Autorita' nazionale anticorruzione sui compiti di trasparenza e di prevenzione della corruzione nelle pubbliche amministrazioni, le funzioni della predetta Autorita' in materia di misurazione e valutazione della performance, di cui agli articoli 7, 8, 9, 10, 12, 13 e 14 del decreto legislativo 27 ottobre 2009, n. 150, sono trasferite al Dipartimento della funzione pubblica della Presidenza del Consiglio dei ministri, a decorrere dalla data di entrata in vigore della legge di conversione del presente decreto". -------------- AGGIORNAMENTO (12) Il D.P.R. 24 giugno 2022, n. 81, ha disposto (con l'art. 1, comma 1, lettera c)) che "Ai sensi di quanto previsto dall'articolo 6, comma 1, del decreto-legge 9 giugno 2021, n. 80, convertito, con modificazioni, dalla legge 6 agosto 2021, n. 113, per le amministrazioni pubbliche di cui all'articolo 1, comma 2, del decreto legislativo 30 marzo 2001, n. 165, con piu' di cinquanta dipendenti, sono soppressi, in quanto assorbiti nelle apposite sezioni del Piano integrato di attivita' e organizzazione (PIAO), gli adempimenti inerenti ai piani di cui alle seguenti disposizioni: [...] c) articolo 10, commi 1, lettera a), e 1-ter, del decreto legislativo 27 ottobre 2009, n. 150 (Piano della performance)".

## Trasparenza e rendicontazione della performance

### Art. 11.

((ARTICOLO ABROGATO DAL D.LGS. 14 MARZO 2013, N. 33)) ((5))

--------------- AGGIORNAMENTO (5) Il D.Lgs. 14 marzo 2013, n. 33 ha disposto (con l'art. 52, comma 5) che "Dalla data di entrata in vigore del presente decreto, qualsiasi rinvio al Programma triennale per la trasparenza e l'integrita' di cui all'articolo 11 del decreto legislativo 27 ottobre 2009, n. 150, si intende riferito all'articolo 10".

## Soggetti del processo di misurazione e valutazione della performance

### Art. 12. - Soggetti

1. Nel processo di misurazione e valutazione della performance organizzativa e individuale delle amministrazioni pubbliche intervengono: ((a) il Dipartimento della funzione pubblica titolare delle funzioni di promozione, indirizzo e coordinamento, esercitate secondo le previsioni del decreto adottato ai sensi dell'articolo 19, comma 10, del decreto-legge n. 90 del 2014;)) b) gli Organismi indipendenti di valutazione della performance di cui all'articolo 14; c) l'organo di indirizzo politico amministrativo di ciascuna amministrazione; d) i dirigenti di ciascuna amministrazione. (8)

-------------- AGGIORNAMENTO (8) Il D.L. 24 giugno 2014, n. 90 convertito con modificazioni dalla L. 11 agosto 2014, n. 114 ha disposto (con l'art. 19, comma 9) che "Al fine di concentrare l'attivita' dell'Autorita' nazionale anticorruzione sui compiti di trasparenza e di prevenzione della corruzione nelle pubbliche amministrazioni, le funzioni della predetta Autorita' in materia di misurazione e valutazione della performance, di cui agli articoli 7, 8, 9, 10, 12, 13 e 14 del decreto legislativo 27 ottobre 2009, n. 150, sono trasferite al Dipartimento della funzione pubblica della Presidenza del Consiglio dei ministri, a decorrere dalla data di entrata in vigore della legge di conversione del presente decreto".

### Art. 13. - ((Autorita' nazionale anticorruzione))

1. ((La Commissione istituita in attuazione dell'articolo 4, comma 2, lettera f), della legge 4 marzo 2009, n. 15, e ridenominata Autorita' nazionale anticorruzione ai sensi dell'articolo 1 della legge 6 novembre 2012, n. 190 e dell'articolo 19 del decreto-legge 24 giugno 2014, n. 90,)) opera in posizione di indipendenza di giudizio e di valutazione e in piena autonomia, in collaborazione con la Presidenza del Consiglio dei Ministri - Dipartimento della funzione pubblica e con il Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato ed eventualmente in raccordo con altri enti o istituzioni pubbliche ((...)).

2. Mediante intesa tra la Conferenza delle Regioni e delle Province autonome, l'Anci, l'Upi e ((l'Autorita')) sono definiti i protocolli di collaborazione per la realizzazione delle attivita' di cui ai commi ((...)) 6 e 8.

3. L'Autorita' e' organo collegiale composto dal presidente e da quattro componenti scelti tra esperti di elevata professionalita', anche estranei all'amministrazione, con comprovate competenze in Italia e all'estero, sia nel settore pubblico che in quello privato, di notoria indipendenza e comprovata esperienza in materia di contrasto alla corruzione ((...)). Il presidente e i componenti sono nominati, tenuto conto del principio delle pari opportunita' di genere, con decreto del Presidente della Repubblica, previa deliberazione del Consiglio dei ministri, previo parere favorevole delle Commissioni parlamentari competenti espresso a maggioranza dei due terzi dei componenti. Il presidente e' nominato su proposta del Ministro per la pubblica amministrazione e la semplificazione, di concerto con il Ministro della giustizia e il Ministro dell'interno; i componenti sono nominati su proposta del Ministro per la pubblica amministrazione e la semplificazione. Il presidente e i componenti dell'Autorita' non possono essere scelti tra persone che rivestono incarichi pubblici elettivi o cariche in partiti politici o in organizzazioni sindacali o che abbiano rivestito tali incarichi e cariche nei tre anni precedenti la nomina e, in ogni caso, non devono avere interessi di qualsiasi natura in conflitto con le funzioni dell'Autorita'. I componenti sono nominati per un periodo di sei anni e non possono essere confermati nella carica.

4. La struttura operativa ((dell'Autorita')) e' diretta da un Segretario generale nominato con deliberazione ((dell'Autorita')) medesima tra soggetti aventi specifica professionalita' ed esperienza gestionale-organizzativa nel campo del lavoro pubblico. ((L'Autorita')) definisce con propri regolamenti le norme concernenti il proprio funzionamento ((...)). ((PERIODO SOPPRESSO DAL D.LGS. 25 MAGGIO 2017, N. 74)). Nei limiti delle disponibilita' di bilancio ((l'Autorita')) puo' avvalersi di non piu' di 10 esperti di elevata professionalita' ed esperienza sui temi ((...)) della prevenzione e della lotta alla corruzione, con contratti di diritto privato di collaborazione autonoma. ((PERIODO SOPPRESSO DAL D.LGS. 25 MAGGIO 2017, N. 74)). Puo' inoltre richiedere indagini, accertamenti e relazioni all'Ispettorato per la funzione pubblica.

5. COMMA ABROGATO DAL D.P.R. 9 MAGGIO 2016, N. 105.

6. ((L'Autorita')) nel rispetto dell'esercizio e delle responsabilita' autonome di valutazione proprie di ogni amministrazione:

- a) LETTERA ABROGATA DAL D.P.R. 9 MAGGIO 2016, N. 105;
- b) LETTERA ABROGATA DAL D.P.R. 9 MAGGIO 2016, N. 105;
- c) LETTERA ABROGATA DAL D.P.R. 9 MAGGIO 2016, N. 105;
- d) LETTERA ABROGATA DAL D.P.R. 9 MAGGIO 2016, N. 105;
- e) adotta le linee guida per la predisposizione dei Programma triennale per la trasparenza e l'integrita' di cui ((all'articolo 10, comma 8, del decreto legislativo 14 marzo 2013, n. 33));
- f) LETTERA ABROGATA DAL D.P.R. 9 MAGGIO 2016, N. 105;
- g) LETTERA ABROGATA DAL D.P.R. 9 MAGGIO 2016, N. 105;
- h) LETTERA ABROGATA DAL D.P.R. 9 MAGGIO 2016, N. 105;
- i) LETTERA ABROGATA DAL D.P.R. 9 MAGGIO 2016, N. 105;
- l) LETTERA ABROGATA DAL D.P.R. 9 MAGGIO 2016, N. 105;
- m) ((LETTERA SOPPRESSA DAL D.LGS. 25 MAGGIO 2017, N. 74));
- n) LETTERA ABROGATA DAL D.P.R. 9 MAGGIO 2016, N. 105;
- o) LETTERA ABROGATA DAL D.P.R. 9 MAGGIO 2016, N. 105;
- p) ((LETTERA SOPPRESSA DAL D.LGS. 25 MAGGIO 2017, N. 74));

7. COMMA ABROGATO DAL D.L. 24 GIUGNO 2014, N. 90, CONVERTITO CON MODIFICAZIONI DALLA L.11 AGOSTO 2014, N. 114.

8. Presso ((l'Autorita')) e' istituita la Sezione per l'integrita' nelle amministrazioni pubbliche con la funzione di favorire, all'interno della amministrazioni pubbliche, la diffusione della legalita' e della trasparenza e sviluppare interventi a favore della cultura dell'integrita'. La Sezione promuove la trasparenza e l'integrita' nelle amministrazioni pubbliche; a tale fine predispone le linee guida del Programma triennale per l'integrita' e la trasparenza di cui articolo 11, ne verifica l'effettiva adozione e vigila sul rispetto degli obblighi in materia di trasparenza da parte di ciascuna amministrazione.

9. I risultati dell'attivita' ((dell'Autorita')) sono pubblici. ((L'Autorita')) assicura la disponibilita', per le associazioni di consumatori o utenti, i centri di ricerca e ogni altro osservatore qualificato, di tutti i dati sui quali la valutazione si basa e trasmette una relazione annuale sulle proprie attivita' al Ministro per l'attuazione del programma di Governo.

10. Dopo cinque anni, dalla data di costituzione, ((l'Autorita')) affida ad un valutatore indipendente un'analisi dei propri risultati ed un giudizio sull'efficacia della sua attivita' e sull'adeguatezza della struttura di gestione, anche al fine di formulare eventuali proposte di integrazioni o modificazioni dei propri compiti. L'esito della valutazione e le eventuali raccomandazioni sono trasmesse al Ministro per la pubblica amministrazione e l'innovazione e pubblicate sul sito istituzionale ((dell'Autorita')).

11. Con decreto del Ministro per la pubblica amministrazione e l'innovazione, di concerto con il Ministro dell'economia e delle finanze, sono stabilite le modalita' di organizzazione, le norme regolatrici dell'autonoma gestione finanziaria ((dell'Autorita')) e fissati i compensi per i componenti.

((

12. Il sistema di valutazione delle attivita' amministrative delle universita' e degli enti di ricerca di cui al Capo I del decreto legislativo 31 dicembre 2009, n. 213, e' svolto dall'Agenzia nazionale di valutazione del sistema universitario e della ricerca (ANVUR) nel rispetto del presente decreto.

))

13. Agli oneri derivanti dal presente articolo pari a due milioni di euro per l'anno 2009 e a 8 milioni di euro a decorrere dall'anno 2010 si provvede nei limiti dell'autorizzazione di spesa di cui all'articolo 4, comma 3, primo periodo, della legge 4 marzo 2009, n. 15. All'attuazione della lettera p) del comma 6 si provvede nell'ambito dell'autorizzazione di spesa di cui all'articolo 4, comma 3, secondo periodo, della legge 4 marzo 2009, n. 15, ferme restando le risorse da destinare alle altre finalita' di cui al medesimo comma 3 dell'articolo 4. (8)

------------ AGGIORNAMENTO (3) Il D.L. 29 dicembre 2010, n. 225, convertito con modificazioni dalla L. 26 febbraio 2011, n. 10, ha disposto (con l'art. 2, comma 12-decies)che la facolta' di essere collocati fuori ruolo, su richiesta, prevista dal presente articolo, comma 3, ultimo periodo, come modificato ai sensi del medesimo decreto-legge, si applica anche ai componenti in carica alla data di entrata in vigore della legge di conversione dello stesso decreto-legge che continuano ad operare fino al termine del mandato. ------------ AGGIORNAMENTO (8) Il D.L. 24 giugno 2014, n. 90, convertito con modificazioni dalla L. 11 agosto 2014, n. 114 ha disposto (con l'art. 19, commi 1 e 2) che l'Autorita' di vigilanza sui contratti pubblici di lavori, servizi e forniture, di cui all'articolo 6 del D.Lgs. 12 aprile 2006, n. 163 e' soppressa e i compiti e le funzioni svolti dall'Autorita' di vigilanza sui contratti pubblici di lavori, servizi e forniture sono trasferiti all'Autorita' nazionale anticorruzione e per la valutazione e la trasparenza (ANAC), di cui al presente articolo, che e' ridenominata Autorita' nazionale anticorruzione. Ha inoltre disposto (con l'art. 19, comma 9) che "Al fine di concentrare l'attivita' dell'Autorita' nazionale anticorruzione sui compiti di trasparenza e di prevenzione della corruzione nelle pubbliche amministrazioni, le funzioni della predetta Autorita' in materia di misurazione e valutazione della performance, di cui agli articoli 7, 8, 9, 10, 12, 13 e 14 del decreto legislativo 27 ottobre 2009, n. 150, sono trasferite al Dipartimento della funzione pubblica della Presidenza del Consiglio dei ministri, a decorrere dalla data di entrata in vigore della legge di conversione del presente decreto. Con riguardo al solo trasferimento delle funzioni di cui all'articolo 13, comma 6, lettere m) e p), del decreto legislativo n. 150 del 2009, relativamente ai progetti sperimentali e al Portale della trasparenza, detto trasferimento di funzioni deve avvenire previo accordo tra il Dipartimento della funzione pubblica e l'Autorita' nazionale anticorruzione, anche al fine di individuare i progetti che possono piu' opportunamente rimanere nell'ambito della medesima Autorita' nazionale anticorruzione".

### Art. 14. - Organismo indipendente di valutazione della performance

1. Ogni amministrazione, singolarmente o in forma associata, senza nuovi o maggiori oneri per la finanza pubblica, si dota di un Organismo indipendente di valutazione della performance. ((Il Dipartimento della funzione pubblica assicura la corretta istituzione e composizione degli Organismi indipendenti di valutazione.))

2. L'Organismo di cui al comma 1 sostituisce i servizi di controllo interno, comunque denominati, di cui al decreto legislativo 30 luglio 1999, n. 286, ed esercita, in piena autonomia, le attivita' di cui al comma 4. Esercita, altresi', le attivita' di controllo strategico di cui all'articolo 6, comma 1, del citato decreto legislativo n. 286 del 1999, e riferisce, in proposito, direttamente all'organo di indirizzo politico-amministrativo.

((

2-bis. L'Organismo indipendente di valutazione della performance e' costituito, di norma, in forma collegiale con tre componenti. Il Dipartimento della funzione pubblica definisce i criteri sulla base dei quali le amministrazioni possono istituire l'Organismo in forma monocratica.

))

((

2-ter. Il Dipartimento della funzione pubblica individua i casi in cui sono istituiti Organismi in forma associata tra piu' pubbliche amministrazioni.

))

3. COMMA ABROGATO DAL D.P.R. 9 MAGGIO 2016, N. 105.

4. L'Organismo indipendente di valutazione della performance:

- a) monitora il funzionamento complessivo del sistema della valutazione, della trasparenza e integrita' dei controlli interni ed elabora una relazione annuale sullo stato dello stesso ((, anche formulando proposte e raccomandazioni ai vertici amministrativi));
- b) comunica tempestivamente le criticita' riscontrate ai competenti organi interni di governo ed amministrazione, nonche' alla Corte dei conti ((e al Dipartimento della funzione pubblica));
- c) valida la Relazione sulla performance di cui all'articolo 10 ((, a condizione che la stessa sia redatta in forma sintetica, chiara e di immediata comprensione ai cittadini e agli altri utenti finali)) e ne assicura la visibilita' attraverso la pubblicazione sul sito istituzionale dell'amministrazione;
- d) garantisce la correttezza dei processi di misurazione e valutazione ((con particolare riferimento alla significativa differenziazione dei giudizi di cui all'articolo 9, comma 1, lettera d) )), nonche' dell'utilizzo dei premi di cui al Titolo III, secondo quanto previsto dal presente decreto, dai contratti collettivi nazionali, dai contratti integrativi, dai regolamenti interni all'amministrazione, nel rispetto del principio di valorizzazione del merito e della professionalita';
- e) propone, sulla base del sistema di cui all'articolo 7, all'organo di indirizzo politico-amministrativo, la valutazione annuale dei dirigenti di vertice e l'attribuzione ad essi dei premi di cui al Titolo III;
- f) e' responsabile della corretta applicazione delle linee guida, delle metodologie e degli strumenti predisposti ((dal Dipartimento della funzione pubblica sulla base del decreto adottato ai sensi dell'articolo 19, comma 10, del decreto legge n. 90 del 2014));
- g) promuove e attesta l'assolvimento degli obblighi relativi alla trasparenza e all'integrita' di cui al presente Titolo;
- h) verifica i risultati e le buone pratiche di promozione delle pari opportunita'.

((

4-bis. Gli Organismi indipendenti di valutazione esercitano i compiti di cui al comma 4 e, in particolare, procedono alla validazione della Relazione sulla performance, tenendo conto anche delle risultanze delle valutazioni realizzate con il coinvolgimento dei cittadini o degli altri utenti finali per le attivita' e i servizi rivolti, nonche', ove presenti, dei risultati prodotti dalle indagini svolte dalle agenzie esterne di valutazione e dalle analisi condotte dai soggetti appartenenti alla rete nazionale per la valutazione delle amministrazioni pubbliche, di cui al decreto emanato in attuazione dell'articolo 19 del decreto-legge n. 90 del 2014, e dei dati e delle elaborazioni forniti dall'amministrazione, secondo le modalita' indicate nel sistema di cui all'articolo 7.

))

((

4-ter. Nell'esercizio delle funzioni di cui al comma 4, l'Organismo indipendente di valutazione ha accesso a tutti gli atti e documenti in possesso dell'amministrazione, utili all'espletamento dei propri compiti, nel rispetto della disciplina in materia di protezione dei dati personali. Tale accesso e' garantito senza ritardo. L'Organismo ha altresi' accesso diretto a tutti i sistemi informativi dell'amministrazione, ivi incluso il sistema di controllo di gestione, e puo' accedere a tutti i luoghi all'interno dell'amministrazione, al fine di svolgere le verifiche necessarie all'espletamento delle proprie funzioni, potendo agire anche in collaborazione con gli organismi di controllo di regolarita' amministrativa e contabile dell'amministrazione. Nel caso di riscontro di gravi irregolarita', l'Organismo indipendente di valutazione effettua ogni opportuna segnalazione agli organi competenti.

))

5. COMMA ABROGATO DAL D.P.R. 9 MAGGIO 2016, N. 105.

6. La validazione della Relazione sulla performance di cui al comma 4, lettera c), e' condizione inderogabile per l'accesso agli strumenti per premiare il merito di cui al Titolo III.

7. COMMA ABROGATO DAL D.P.R. 9 MAGGIO 2016, N. 105.

8. I componenti dell'Organismo indipendente di valutazione non possono essere nominati ((tra i dipendenti dell'amministrazione interessata o)) tra soggetti che rivestano incarichi pubblici elettivi o cariche in partiti politici o in organizzazioni sindacali ovvero che abbiano rapporti continuativi di collaborazione o di consulenza con le predette organizzazioni, ovvero che abbiano rivestito simili incarichi o cariche o che abbiano avuto simili rapporti nei tre anni precedenti la designazione.

9. Presso l'Organismo indipendente di valutazione e' costituita, senza nuovi o maggiori oneri per la finanza pubblica, una struttura tecnica permanente per la misurazione della performance, dotata delle risorse necessarie all'esercizio delle relative funzioni.

10. Il responsabile della struttura tecnica permanente deve possedere una specifica professionalita' ed esperienza nel campo della misurazione della performance nelle amministrazioni pubbliche.

11. Agli oneri derivanti dalla costituzione e dal funzionamento degli organismi di cui al presente articolo si provvede nei limiti delle risorse attualmente destinate ai servizi di controllo interno. (8)

-------------- AGGIORNAMENTO (8) Il D.L. 24 giugno 2014, n. 90 convertito con modificazioni dalla L. 11 agosto 2014, n. 114 ha disposto (con l'art. 19, comma 9) che "Al fine di concentrare l'attivita' dell'Autorita' nazionale anticorruzione sui compiti di trasparenza e di prevenzione della corruzione nelle pubbliche amministrazioni, le funzioni della predetta Autorita' in materia di misurazione e valutazione della performance, di cui agli articoli 7, 8, 9, 10, 12, 13 e 14 del decreto legislativo 27 ottobre 2009, n. 150, sono trasferite al Dipartimento della funzione pubblica della Presidenza del Consiglio dei ministri, a decorrere dalla data di entrata in vigore della legge di conversione del presente decreto".

### Art. 14-bis. - (Elenco, durata e requisiti dei componenti degli OIV)

1. Il Dipartimento della funzione pubblica tiene e aggiorna l'Elenco nazionale dei componenti degli Organismi indipendenti di valutazione, secondo le modalita' indicate nel decreto adottato ai sensi dell'articolo 19, comma 10, del decreto-legge n. 90 del 2014.

2. La nomina dell'organismo indipendente di valutazione e' effettuata dall'organo di indirizzo politico-amministrativo, tra gli iscritti all'elenco di cui al comma 1, previa procedura selettiva pubblica ((avvalendosi del Portale del reclutamento di cui all'articolo 3, comma 7, della legge 19 giugno 2019, n. 56.)).

3. La durata dell'incarico di componente dell'Organismo indipendente di valutazione e' di tre anni, rinnovabile una sola volta presso la stessa amministrazione, previa procedura selettiva pubblica.

4. L'iscrizione all'Elenco nazionale dei componenti degli Organismi indipendenti di valutazione avviene sulla base di criteri selettivi che favoriscono il merito e le conoscenze specialistiche, nel rispetto di requisiti generali, di integrita' e di competenza individuati ai sensi del comma 1.

5. Con le modalita' di cui al comma 1, sono stabiliti gli obblighi di aggiornamento professionale e formazione continua posti a carico degli iscritti all'elenco nazionale dei componenti degli organismi indipendenti di valutazione.

6. Le nomine e i rinnovi dei componenti degli Organismi indipendenti di valutazione sono nulli in caso di inosservanza delle modalita' e dei requisiti stabiliti dall'articolo 14 e dal presente articolo. Il Dipartimento della funzione pubblica segnala alle amministrazioni interessate l'inosservanza delle predette disposizioni.

### Art. 15. - Responsabilita' dell'organo di indirizzo politico-amministrativo

1. L'organo di indirizzo politico-amministrativo promuove la cultura della responsabilita' per il miglioramento della performance, del merito, della trasparenza e dell'integrita'.

2. L'organo di indirizzo politico-amministrativo di ciascuna amministrazione:

- a) emana le direttive generali contenenti gli indirizzi strategici;
- b) definisce in collaborazione con i vertici dell'amministrazione il Piano e la Relazione di cui all'articolo 10, comma 1, lettere a) e b);
- c) verifica il conseguimento effettivo degli obiettivi strategici;
- d) definisce il Programma triennale per la trasparenza e l'integrita' di cui all'articolo 11, nonche' gli eventuali aggiornamenti annuali.

### Art. 16. - Norme per gli Enti territoriali e il Servizio sanitario nazionale

1. ((COMMA ABROGATO DAL D.LGS. 25 MAGGIO 2017, N. 74)).

((

2. Le regioni, anche per quanto concerne i propri enti e le amministrazioni del Servizio sanitario nazionale, e gli enti locali adeguano i propri ordinamenti ai principi contenuti negli articoli 3, 4, 5, comma 2, 7, 9 e 15, comma 1. Per l'attuazione delle restanti disposizioni di cui al presente decreto, si procede tramite accordo da sottoscrivere ai sensi dell'articolo 4 del decreto legislativo n. 281 del 1997 in sede di Conferenza unificata.

))

3. ((COMMA ABROGATO DAL D.LGS. 25 MAGGIO 2017, N. 74)).

## MERITO E PREMI CAPO I Disposizioni generali

### Art. 17. - Oggetto e finalita'

1. Le disposizioni del presente titolo recano strumenti di valorizzazione del merito e metodi di incentivazione della produttivita' e della qualita' della prestazione lavorativa informati a principi di selettivita' e concorsualita' nelle progressioni di carriera e nel riconoscimento degli incentivi.

2. Dall'applicazione delle disposizioni del presente Titolo non devono derivare nuovi o maggiori oneri per la finanza pubblica. Le amministrazioni interessate utilizzano a tale fine le risorse umane, finanziarie e strumentali disponibili a legislazione vigente.

### Art. 18. - Criteri e modalita' per la valorizzazione del merito ed incentivazione della performance

1. Le amministrazioni pubbliche promuovono il merito e il miglioramento della performance organizzativa e individuale, anche attraverso l'utilizzo di sistemi premianti selettivi, secondo logiche meritocratiche, nonche' valorizzano i dipendenti che conseguono le migliori performance attraverso l'attribuzione selettiva di incentivi sia economici sia di carriera.

2. E' vietata la distribuzione in maniera indifferenziata o sulla base di automatismi di incentivi e premi collegati alla performance in assenza delle verifiche e attestazioni sui sistemi di misurazione e valutazione adottati ai sensi del presente decreto.

### Art. 19. - (( (Criteri per la differenziazione delle valutazioni). ))

((

1. Il contratto collettivo nazionale, nell'ambito delle risorse destinate al trattamento economico accessorio collegato alla performance ai sensi dell'articolo 40, comma 3-bis, del decreto legislativo 30 marzo 2001, n. 165, stabilisce la quota delle risorse destinate a remunerare, rispettivamente, la performance organizzativa e quella individuale e fissa criteri idonei a garantire che alla significativa differenziazione dei giudizi di cui all'articolo 9, comma 1, lettera d), corrisponda un'effettiva diversificazione dei trattamenti economici correlati.

2. Per i dirigenti, il criterio di attribuzione dei premi di cui al comma 1 e' applicato con riferimento alla retribuzione di risultato.))

------------- AGGIORNAMENTO (4) Il D.Lgs. 1 agosto 2011, n. 141 ha disposto (con l'art. 6, comma 1) che "La differenziazione retributiva in fasce prevista dagli articoli 19, commi 2 e 3, e 31, comma 2, del decreto legislativo 27 ottobre 2009, n. 150, si applica a partire dalla tornata di contrattazione collettiva successiva a quella relativa al quadriennio 2006-2009. Ai fini previsti dalle citate disposizioni, nelle more dei predetti rinnovi contrattuali, possono essere utilizzate le eventuali economie aggiuntive destinate all'erogazione dei premi dall'articolo 16, comma 5, del decreto-legge 6 luglio 2011, n. 98, convertito, con modificazioni, dalla legge 15 luglio 2011, n. 111".

### Art. 19-bis. - (( (Partecipazione dei cittadini e degli altri utenti finali). ))

((

1. I cittadini, anche in forma associata, partecipano al processo di misurazione delle performance organizzative, anche comunicando direttamente all'Organismo indipendente di valutazione il proprio grado di soddisfazione per le attivita' e per i servizi erogati, secondo le modalita' stabilite dallo stesso Organismo.

2. Ciascuna amministrazione adotta sistemi di rilevazione del grado di soddisfazione degli utenti e dei cittadini in relazione alle attivita' e ai servizi erogati, favorendo ogni piu' ampia forma di partecipazione e collaborazione dei destinatari dei servizi, secondo quanto stabilito dall'articolo 8, comma 1, lettere c) ed e).

3. Gli utenti interni alle amministrazioni partecipano al processo di misurazione delle performance organizzative in relazione ai servizi strumentali e di supporto secondo le modalita' individuate dall'Organismo indipendente di valutazione.

4. I risultati della rilevazione del grado di soddisfazione dei soggetti di cui ai commi da 1 a 3 sono pubblicati, con cadenza annuale, sul sito dell'amministrazione.

5. L'organismo indipendente di valutazione verifica l'effettiva adozione dei predetti sistemi di rilevazione, assicura la pubblicazione dei risultati in forma chiara e comprensibile e ne tiene conto ai fini della valutazione della performance organizzativa dell'amministrazione e in particolare, ai fini della validazione della Relazione sulla performance di cui all'articolo 14, comma 4, lettera c).

))

## Premi

### Art. 20. - Strumenti

1. Gli strumenti per premiare il merito e le professionalita' sono:

- a) il bonus annuale delle eccellenze, di cui all'articolo 21;
- b) il premio annuale per l'innovazione, di cui all'articolo 22;
- c) le progressioni economiche, di cui all'articolo 23;
- d) le progressioni di carriera, di cui all'articolo 24;
- e) l'attribuzione di incarichi e responsabilita', di cui all'articolo 25;
- f) l'accesso a percorsi di alta formazione e di crescita professionale, in ambito nazionale e internazionale, di cui all'articolo 26.

2. Gli incentivi di cui alle lettere a), b), c), ed e) del comma 1 sono riconosciuti a valere sulle risorse disponibili per la contrattazione collettiva integrativa.

### Art. 21. - Bonus annuale delle eccellenze

((

1. Ogni amministrazione pubblica, nell'ambito delle risorse di cui al comma 3-bis dell'articolo 45 del decreto legislativo 30 marzo 2001, n. 165, puo' attribuire un bonus annuale al quale concorre il personale, dirigenziale e non, cui e' attribuita una valutazione di eccellenza.

))

2. Nei limiti delle risorse disponibili, la contrattazione collettiva nazionale determina l'ammontare del bonus annuale delle eccellenze.

3. Il personale premiato con il bonus annuale di cui al comma 1 puo' accedere agli strumenti premianti di cui agli articoli 22 e 26 a condizione che rinunci al bonus stesso.

4. Entro il mese di aprile di ogni anno, le amministrazioni pubbliche, a conclusione del processo di valutazione della performance, assegnano al personale il bonus annuale relativo all'esercizio precedente.

### Art. 22. - Premio annuale per l'innovazione

1. Ogni amministrazione pubblica istituisce un premio annuale per l'innovazione, di valore pari all'ammontare del bonus annuale di eccellenza, di cui all'articolo 21, per ciascun dipendente premiato.

2. Il premio viene assegnato al miglior progetto realizzato nell'anno, in grado di produrre un significativo cambiamento dei servizi offerti o dei processi interni di lavoro, con un elevato impatto sulla performance dell'organizzazione.

3. L'assegnazione del premio per l'innovazione compete all'Organismo indipendente di valutazione della performance di cui all'articolo 14, sulla base di una valutazione comparativa delle candidature presentate da singoli dirigenti e dipendenti o da gruppi di lavoro.

4. Il progetto premiato e' l'unico candidabile al Premio nazionale per l'innovazione nelle amministrazioni pubbliche, promosso dal Ministro per la pubblica amministrazione e l'innovazione.

### Art. 23. - Progressioni economiche

1. Le amministrazioni pubbliche riconoscono selettivamente le progressioni economiche di cui all'articolo 52, comma 1-bis, del decreto legislativo 30 marzo 2001, n.165, ((...)) sulla base di quanto previsto dai contratti collettivi nazionali e integrativi di lavoro e nei limiti delle risorse disponibili.

2. Le progressioni economiche sono attribuite in modo selettivo, ad una quota limitata di dipendenti, in relazione allo sviluppo delle competenze professionali ed ai risultati individuali e collettivi rilevati dal sistema di valutazione.

3. ((COMMA ABROGATO DAL D.LGS. 25 MAGGIO 2017, N. 74)).

### Art. 24. - Progressioni di carriera

1. Ai sensi dell'articolo 52, comma 1-bis, del decreto legislativo n. 165 del 2001, ((...)) le amministrazioni pubbliche, a decorrere dal 1° gennaio 2010, coprono i posti disponibili nella dotazione organica attraverso concorsi pubblici, con riserva non superiore al cinquanta per cento a favore del personale interno, nel rispetto delle disposizioni vigenti in materia di assunzioni.

2. L'attribuzione dei posti riservati al personale interno e' finalizzata a riconoscere e valorizzare le competenze professionali sviluppate dai dipendenti, in relazione alle specifiche esigenze delle amministrazioni.

3. ((COMMA ABROGATO DAL D.LGS. 25 MAGGIO 2017, N. 74)).

### Art. 25. - Attribuzione di incarichi e responsabilita'

1. Le amministrazioni pubbliche favoriscono la crescita professionale e la responsabilizzazione dei dipendenti pubblici ai fini del continuo miglioramento dei processi e dei servizi offerti.

2. La professionalita' sviluppata e attestata dal sistema di misurazione e valutazione costituisce criterio per l'assegnazione di incarichi e responsabilita' secondo criteri oggettivi e pubblici.

### Art. 26. - Accesso a percorsi di alta formazione e di crescita professionale

1. Le amministrazioni pubbliche riconoscono e valorizzano i contributi individuali e le professionalita' sviluppate dai dipendenti e a tali fini:

- a) promuovono l'accesso privilegiato dei dipendenti a percorsi di alta formazione in primarie istituzioni educative nazionali e internazionali;
- b) favoriscono la crescita professionale e l'ulteriore sviluppo di competenze dei dipendenti, anche attraverso periodi di lavoro presso primarie istituzioni pubbliche e private, nazionali e internazionali.

2. Gli incentivi di cui al comma 1 sono riconosciuti nei limiti delle risorse disponibili di ciascuna amministrazione.

### Art. 27. - Premio di efficienza

1. Fermo restando quanto disposto dall'articolo 61 del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133, e dall'articolo 2, commi 33 e 34, della legge 22 dicembre 2008, n. 203, una quota fino al 30 per cento dei risparmi sui costi di funzionamento derivanti da processi di ristrutturazione, riorganizzazione e innovazione all'interno delle pubbliche amministrazioni e' destinata, in misura fino a due terzi, a premiare, secondo criteri generali definiti dalla contrattazione collettiva integrativa, il personale direttamente e proficuamente coinvolto e per la parte residua ad incrementare le somme disponibili per la contrattazione stessa.

2. Le risorse di cui al comma 1 possono essere utilizzate solo se i risparmi sono stati documentati nella Relazione di performance, validati dall'Organismo di valutazione di cui all'articolo 14 e verificati dal Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato.

3. Le risorse di cui al comma 1 per le regioni, anche per quanto concerne i propri enti e le amministrazioni del Servizio sanitario nazionale, e i relativi enti dipendenti, nonche' per gli enti locali possono essere utilizzate solo se i risparmi sono stati documentati nella Relazione di performance e validati dal proprio organismo di valutazione.

### Art. 28. - Qualita' dei servizi pubblici

1. Il comma 2 dell'articolo 11 del decreto legislativo 30 luglio 1999, n. 286, e' sostituito dal seguente: «2. Le modalita' di definizione, adozione e pubblicizzazione degli standard di qualita', i casi e le modalita' di adozione delle carte dei servizi, i criteri di misurazione della qualita' dei servizi, le condizioni di tutela degli utenti, nonche' i casi e le modalita' di indennizzo automatico e forfettario all'utenza per mancato rispetto degli standard di qualita' sono stabilite con direttive, aggiornabili annualmente, del Presidente del Consiglio dei Ministri, su proposta della Commissione per la valutazione, la trasparenza e l'integrita' nelle amministrazioni pubbliche. Per quanto riguarda i servizi erogati direttamente o indirettamente dalle regioni e dagli enti locali, si provvede con atti di indirizzo e coordinamento adottati d'intesa con la Conferenza unificata di cui al decreto legislativo 28 agosto 1997, n. 281, su proposta della Commissione per la valutazione, la trasparenza e l'integrita' nelle amministrazioni pubbliche.».

## Norme finali, transitorie e abrogazioni

### Art. 29. - Inderogabilita'

1. Fermo restando quanto previsto dall'articolo 31, per le regioni, anche per quanto concerne i propri enti e le amministrazioni del Servizio sanitario nazionale, e per gli enti locali, le disposizioni del presente Titolo hanno carattere imperativo, non possono essere derogate dalla contrattazione collettiva e sono inserite di diritto nei contratti collettivi ai sensi e per gli effetti degli articoli 1339 e 1419, secondo comma, del codice civile, a decorrere dal periodo contrattuale successivo a quello in corso alla data di entrata in vigore del presente decreto.

### Art. 30. - Norme transitorie e abrogazioni

1. La Commissione di cui all'articolo 13 e' costituita entro 30 giorni dalla data di entrata in vigore del presente decreto.

2. Gli Organismi indipendenti di cui all'articolo 14 sono costituiti entro il 30 aprile 2010. Fino alla loro costituzione continuano ad operare gli uffici e i soggetti preposti all'attivita' di valutazione e controllo strategico di cui all'articolo 6 del decreto legislativo 30 luglio 1999, n. 286.

3. In sede di prima attuazione del presente decreto, gli Organismi indipendenti di cui all'articolo 14 provvedono, entro il 30 settembre 2010, sulla base degli indirizzi della Commissione di cui all'articolo 13 a definire i sistemi di valutazione della performance di cui all'articolo 7 in modo da assicurarne la piena operativita' a decorrere dal 1° gennaio 2011. La Commissione effettua il monitoraggio sui parametri e i modelli di riferimento dei predetti sistemi ai sensi dell'articolo 13, comma 6, lettera d).

4. A decorrere dal 30 aprile 2010 sono abrogate le seguenti disposizioni del decreto legislativo 30 luglio 1999, n. 286:

- a) il terzo periodo dell'articolo 1, comma 2, lettera a);
- b) l'articolo 1, comma 6;
- c) l'articolo 5;
- d) l'articolo 6, commi 2 e 3;
- e) l'articolo 11, comma 3. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'errata-corrige pubblicato in G.U. 10/11/2009, n. 262 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

### Art. 31. - Norme per gli Enti territoriali e il Servizio sanitario nazionale

1. Le regioni, anche per quanto concerne i propri enti e le amministrazioni del Servizio sanitario nazionale, e gli enti locali adeguano i propri ordinamenti ai principi contenuti negli articoli 17, comma 2, 18, ((19,)) 23, commi 1 e 2, 24, commi 1 e 2, 25, 26 e 27, comma 1.

2. ((COMMA ABROGATO DAL D.LGS. 25 MAGGIO 2017, N. 74)).

3. ((COMMA ABROGATO DAL D.LGS. 25 MAGGIO 2017, N. 74)).

4. ((COMMA ABROGATO DAL D.LGS. 25 MAGGIO 2017, N. 74)).

5. ((COMMA ABROGATO DAL D.LGS. 25 MAGGIO 2017, N. 74)).

## NUOVE NORME GENERALI SULL'ORDINAMENTO DEL LAVORO ALLE DIPENDENZE DELLE AMMINISTRAZIONI PUBBLICHE CAPO I Principi generali

### Art. 32. - Oggetto, ambito e finalita'

1. Le disposizioni del presente Capo definiscono la ripartizione tra le materie sottoposte alla legge, nonche' sulla base di questa, ad atti organizzativi e all'autonoma responsabilita' del dirigente nella gestione delle risorse umane e quelle oggetto della contrattazione collettiva.

### Art. 33. - Modifiche all'articolo 2 del decreto legislativo 30 marzo 2001, n. 165

1. All'articolo 2 del decreto legislativo 30 marzo 2001, n. 165, sono apportate le seguenti modificazioni:

- a) al comma 2, alla fine del primo periodo, sono inserite le seguenti parole: «, che costituiscono disposizioni a carattere imperativo»;
- b) al comma 3, dopo le parole: «mediante contratti collettivi» sono inserite le seguenti: «e salvo i casi previsti dal comma 3-ter e 3-quater dell'articolo 40 e le ipotesi di tutela delle retribuzioni di cui all'articolo 47-bis,»;
- c) dopo il comma 3 e' aggiunto il seguente: «3-bis. Nel caso di nullita' delle disposizioni contrattuali per violazione di norme imperative o dei limiti fissati alla contrattazione collettiva, si applicano gli articoli 1339 e 1419, secondo comma, del codice civile.».

### Art. 34. - Modifica all'articolo 5 del decreto legislativo 30 marzo 2001, n. 165

1. All'articolo 5 del decreto legislativo 30 marzo 2001, n. 165, sono apportate le seguenti modificazioni:

- a) il comma 2 e' sostituito dal seguente: «2. Nell'ambito delle leggi e degli atti organizzativi di cui all'articolo 2, comma 1, le determinazioni per l'organizzazione degli uffici e le misure inerenti alla gestione dei rapporti di lavoro sono assunte in via esclusiva dagli organi preposti alla gestione con la capacita' e i poteri del privato datore di lavoro, fatta salva la sola informazione ai sindacati, ove prevista nei contratti di cui all'articolo 9. Rientrano, in particolare, nell'esercizio dei poteri dirigenziali le misure inerenti la gestione delle risorse umane nel rispetto del principio di pari opportunita', nonche' la direzione, l'organizzazione del lavoro nell'ambito degli uffici.»;
- b) dopo il comma 3 e' aggiunto il seguente: «3-bis. Le disposizioni del presente articolo si applicano anche alle Autorita' amministrative indipendenti.».

### Art. 35. - Modifica all'articolo 6 del decreto legislativo 30 marzo 2001, n. 165

1. All'articolo 6 del decreto legislativo 30 marzo 2001, n. 165, dopo il comma 4, e' inserito il seguente: «4-bis. Il documento di programmazione triennale del fabbisogno di personale ed i suoi aggiornamenti di cui al comma 4 sono elaborati su proposta dei competenti dirigenti che individuano i profili professionali necessari allo svolgimento dei compiti istituzionali delle strutture cui sono preposti.».

### Art. 36. - Modifica all'articolo 9 del decreto legislativo 30 marzo 2001, n. 165

1. L'articolo 9, del decreto legislativo 30 marzo 2001, n. 165, e' il sostituito dal seguente: «Art. 9 (Partecipazione sindacale). - 1. Fermo restando quanto previsto dall'articolo 5, comma 2, i contratti collettivi nazionali disciplinano le modalita' e gli istituti della partecipazione.».

## Dirigenza pubblica

### Art. 37. - Oggetto, ambito di applicazione e finalita

1. Le disposizioni del presente capo modificano la disciplina della dirigenza pubblica per conseguire la migliore organizzazione del lavoro e assicurare il progressivo miglioramento della qualita' delle prestazioni erogate al pubblico, utilizzando anche i criteri di gestione e di valutazione del settore privato, al fine di realizzare adeguati livelli di produttivita' del lavoro pubblico, di favorire il riconoscimento di meriti e demeriti, e di rafforzare il principio di distinzione tra le funzioni di indirizzo e controllo spettanti agli organi di governo e le funzioni di gestione amministrativa spettanti alla dirigenza, nel rispetto della giurisprudenza costituzionale in materia, regolando il rapporto tra organi di vertice e dirigenti titolari di incarichi apicali in modo da garantire la piena e coerente attuazione dell'indirizzo politico in ambito amministrativo.

### Art. 38. - Modifica all'articolo 16 del decreto legislativo 30 marzo 2001, n. 165

1. All'articolo 16, comma 1, del decreto legislativo 30 marzo 2001, n. 165, sono apportate le seguenti modificazioni:

- a) dopo la lettera a) e' inserita la seguente: «a-bis) propongono le risorse e i profili professionali necessari allo svolgimento dei compiti dell'ufficio cui sono preposti anche al fine dell'elaborazione del documento di programmazione triennale del fabbisogno di personale di cui all'articolo 6, comma 4; »;
- b) dopo la lettera l) e' aggiunta la seguente: «l-bis) concorrono alla definizione di misure idonee a prevenire e contrastare i fenomeni di corruzione e a controllarne il rispetto da parte dei dipendenti dell'ufficio cui sono preposti.».

### Art. 39. - Modifica all'articolo 17 del decreto legislativo 30 marzo 2001, n. 165

1. All'articolo 17, comma 1, del decreto legislativo 30 marzo 2001, n. 165, sono apportate le seguenti modificazioni:

- a) dopo la lettera d) e' inserita la seguente: «d-bis) concorrono all'individuazione delle risorse e dei profili professionali necessari allo svolgimento dei compiti dell'ufficio cui sono preposti anche al fine dell'elaborazione del documento di programmazione triennale del fabbisogno di personale di cui all'articolo 6, comma 4; »;
- b) alla lettera e), sono aggiunte, in fine, le seguenti parole: «, anche ai sensi di quanto previsto all'articolo 16, comma 1, lettera l-bis»;
- c) dopo la lettera e) e' aggiunta seguente: «e-bis) effettuano la valutazione del personale assegnato ai propri uffici, nel rispetto del principio del merito, ai fini della progressione economica e tra le aree, nonche' della corresponsione di indennita' e premi incentivanti.».

### Art. 40. - Modifica all'articolo 19 del decreto legislativo 30 marzo 2001, n. 165

1. All'articolo 19 del decreto legislativo 30 marzo 2001, n. 165, sono apportate le seguenti modificazioni:

- a) il comma 1 e' sostituito dal seguente: «1. Ai fini del conferimento di ciascun incarico di funzione dirigenziale si tiene conto, in relazione alla natura e alle caratteristiche degli obiettivi prefissati ed alla complessita' della struttura interessata, delle attitudini e delle capacita' professionali del singolo dirigente, dei risultati conseguiti in precedenza nell'amministrazione di appartenenza e della relativa valutazione, delle specifiche competenze organizzative possedute, nonche' delle esperienze di direzione eventualmente maturate all'estero, presso il settore privato o presso altre amministrazioni pubbliche, purche' attinenti al conferimento dell'incarico. Al conferimento degli incarichi e al passaggio ad incarichi diversi non si applica l'articolo 2103 del codice civile.»;
- b) dopo il comma 1 sono inseriti i seguenti: «1-bis. L'amministrazione rende conoscibili, anche mediante pubblicazione di apposito avviso sul sito istituzionale, il numero e la tipologia dei posti di funzione che si rendono disponibili nella dotazione organica ed i criteri di scelta; acquisisce le disponibilita' dei dirigenti interessati e le valuta. 1-ter. Gli incarichi dirigenziali possono essere revocati esclusivamente nei casi e con le modalita' di cui all'articolo 21, comma 1, secondo periodo. L'amministrazione che, in dipendenza dei processi di riorganizzazione ovvero alla scadenza, in assenza di una valutazione negativa, non intende confermare l'incarico conferito al dirigente, e' tenuta a darne idonea e motivata comunicazione al dirigente stesso con un preavviso congruo, prospettando i posti disponibili per un nuovo incarico.»;
- c) al comma 2: 1) dopo il secondo periodo e' inserito il seguente: «La durata dell'incarico puo' essere inferiore a tre anni se coincide con il conseguimento del limite di eta' per il collocamento a riposo dell'interessato.»; 2) in fine, e' aggiunto il seguente periodo: «In caso di primo conferimento ad un dirigente della seconda fascia di incarichi di uffici dirigenziali generali o di funzioni equiparate, la durata dell'incarico e' pari a tre anni. Resta fermo che per i dipendenti statali titolari di incarichi di funzioni dirigenziali ai sensi del presente articolo, ai fini dell'applicazione dell'articolo 43, comma 1, del decreto del Presidente della Repubblica 29 dicembre 1973, n. 1092, e successive modificazioni, l'ultimo stipendio va individuato nell'ultima retribuzione percepita in relazione all'incarico svolto.»;
- d) al comma 3, le parole: «richieste dal comma 6.» sono sostituite dalle seguenti: «e nelle percentuali previste dal comma 6.»;
- e) al comma 6: 1) al terzo periodo, le parole: «sono conferiti a persone di particolare e comprovata qualificazione professionale» sono sostituite dalle seguenti: «sono conferiti, fornendone esplicita motivazione, a persone di particolare e comprovata qualificazione professionale, non rinvenibile nei ruoli dell'Amministrazione»; 2) al terzo periodo, le parole: «o da concrete esperienze di lavoro maturate» sono sostituite dalle seguenti: «e da concrete esperienze di lavoro maturate per almeno un quinquennio»;
- f) dopo il comma 6 sono inseriti i seguenti: «6-bis. Fermo restando il contingente complessivo dei dirigenti di prima o seconda fascia il quoziente derivante dall'applicazione delle percentuali previste dai commi 4, 5-bis e 6, e' arrotondato all'unita' inferiore, se il primo decimale e' inferiore a cinque, o all'unita' superiore, se esso e' uguale o superiore a cinque. 6-ter. Il comma 6 ed il comma 6-bis si applicano alle amministrazioni di cui all'articolo 1, comma 2.»;
- g) al comma 8, le parole: «, al comma 5-bis, limitatamente al personale non appartenente ai ruoli di cui all'articolo 23, e al comma 6,» sono soppresse.

### Art. 41. - Modifica all'articolo 21 del decreto legislativo 30 marzo 2001, n. 165

1. All'articolo 21 del decreto legislativo 30 marzo 2001, n. 165, sono apportate le seguenti modifiche:

- a) il comma 1 e' sostituito dal seguente: «1. Il mancato raggiungimento degli obiettivi accertato attraverso le risultanze del sistema di valutazione di cui al Titolo II del decreto legislativo di attuazione della legge 4 marzo 2009, n. 15, in materia di ottimizzazione della produttivita' del lavoro pubblico e di efficienza e trasparenza delle pubbliche amministrazioni ovvero l'inosservanza delle direttive imputabili al dirigente comportano, previa contestazione e ferma restando l'eventuale responsabilita' disciplinare secondo la disciplina contenuta nel contratto collettivo, l'impossibilita' di rinnovo dello stesso incarico dirigenziale. In relazione alla gravita' dei casi, l'amministrazione puo' inoltre, previa contestazione e nel rispetto del principio del contraddittorio, revocare l'incarico collocando il dirigente a disposizione dei ruoli di cui all'articolo 23 ovvero recedere dal rapporto di lavoro secondo le disposizioni del contratto collettivo.»;
- b) dopo il comma 1, e' inserito il seguente: «1-bis. Al di fuori dei casi di cui al comma 1, al dirigente nei confronti del quale sia stata accertata, previa contestazione e nel rispetto del principio del contraddittorio secondo le procedure previste dalla legge e dai contratti collettivi nazionali, la colpevole violazione del dovere di vigilanza sul rispetto, da parte del personale assegnato ai propri uffici, degli standard quantitativi e qualitativi fissati dall'amministrazione, conformemente agli indirizzi deliberati dalla Commissione di cui all'articolo 13 del decreto legislativo di attuazione della legge 4 marzo 2009, n. 15, in materia di ottimizzazione della produttivita' del lavoro pubblico e di efficienza e trasparenza delle pubbliche amministrazioni, la retribuzione di risultato e' decurtata, sentito il Comitato dei garanti, in relazione alla gravita' della violazione di una quota fino all'ottanta per cento.».

### Art. 42. - Modifica all'articolo 22 del decreto legislativo 30 marzo 2001, n. 165

1. L'articolo 22 del decreto legislativo 30 marzo 2001, n.165, e' sostituito dal seguente: «Art. 22 (Comitato dei garanti). - 1. I provvedimenti di cui all'articolo 21, commi 1 e 1-bis, sono adottati sentito il Comitato dei garanti, i cui componenti, nel rispetto del principio di genere, sono nominati con decreto del Presidente del Consiglio dei Ministri. Il Comitato dura in carica tre anni e l'incarico non e' rinnovabile. 2. Il Comitato dei garanti e' composto da un consigliere della Corte dei conti, designato dal suo Presidente, e da quattro componenti designati rispettivamente, uno dal Presidente della Commissione di cui all'articolo 13 del decreto legislativo di attuazione della legge 4 marzo 2009, n. 15, in materia di ottimizzazione della produttivita' del lavoro pubblico, e di efficienza e trasparenza delle pubbliche amministrazioni, uno dal Ministro per la pubblica amministrazione e l'innovazione, scelto tra un esperto scelto tra soggetti con specifica qualificazione ed esperienza nei settori dell'organizzazione amministrativa e del lavoro pubblico, e due scelti tra dirigenti di uffici dirigenziali generali di cui almeno uno appartenente agli Organismi indipendenti di valutazione, estratti a sorte fra coloro che hanno presentato la propria candidatura. I componenti sono collocati fuori ruolo e il posto corrispondente nella dotazione organica dell'amministrazione di appartenenza e' reso indisponibile per tutta la durata del mandato. Per la partecipazione al Comitato non e' prevista la corresponsione di emolumenti o rimborsi spese. 3. Il parere del Comitato dei garanti viene reso entro il termine di quarantacinque giorni dalla richiesta; decorso inutilmente tale termine si prescinde dal parere.».

### Art. 43. - Modifiche all'articolo 23 del decreto legislativo 30 marzo 2001, n. 165

1. Al terzo periodo del comma 1 dell'articolo 23 del decreto legislativo 30 marzo 2001, n. 165, le parole: "tre anni" sono sostituite dalle seguenti: "cinque anni".

2. Per i dirigenti ai quali sia stato conferito l'incarico di direzione di uffici dirigenziali generali o equivalenti prima della data di entrata in vigore del presente decreto, il termine di cui all'articolo 23, comma 1, terzo periodo, del decreto legislativo n. 165 del 2001, rimane fissato in tre anni. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'errata-corrige pubblicato in G.U. 10/11/2009, n. 262 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

### Art. 44. - Modifica all'articolo 23-bis del decreto legislativo 30 marzo 2001, n. 165

1. All'articolo 23-bis del decreto legislativo 30 marzo 2001, n.165, sono apportate le seguenti modificazioni:

- a) al comma 1, le parole da: «possono» fino a «aspettativa» sono sostituite dalle seguenti: «sono collocati, salvo motivato diniego dell'amministrazione di appartenenza in ordine alle proprie preminenti esigenze organizzative, in aspettativa»;
- b) al comma 2, in fine, sono aggiunte le seguenti parole: «in ordine alle proprie preminenti esigenze organizzative».

### Art. 45. - Modifica all'articolo 24 del decreto legislativo 30 marzo 2001, n. 165

1. All'articolo 24 del decreto legislativo 30 marzo 2001, n. 165, sono apportate le seguenti modifiche:

- a) al comma 1, le parole: «e alle connesse responsabilita'» sono sostituite dalle seguenti: «, alle connesse responsabilita' e ai risultati conseguiti»;
- b) dopo il comma 1 sono inseriti i seguenti: «1-bis. Il trattamento accessorio collegato ai risultati deve costituire almeno il 30 per cento della retribuzione complessiva del dirigente considerata al netto della retribuzione individuale di anzianita' e degli incarichi aggiuntivi soggetti al regime dell'onnicomprensivita'. 1-ter. I contratti collettivi nazionali incrementano progressivamente la componente legata al risultato, in modo da adeguarsi a quanto disposto dal comma 1-bis, entro la tornata contrattuale successiva a quella decorrente dal 1° gennaio 2010, destinando comunque a tale componente tutti gli incrementi previsti per la parte accessoria della retribuzione. La disposizione di cui al comma 1-bis non si applica alla dirigenza del Servizio sanitario nazionale e dall'attuazione del medesimo comma non devono derivare nuovi o maggiori oneri per la finanza pubblica. 1-quater. La parte della retribuzione collegata al raggiungimento dei risultati della prestazione non puo' essere corrisposta al dirigente responsabile qualora l'amministrazione di appartenenza, decorso il periodo transitorio di sei mesi dalla data di entrata in vigore del decreto legislativo di attuazione della legge 4 marzo 2009, n. 15, in materia di ottimizzazione della produttivita' del lavoro pubblico e di efficienza e trasparenza delle pubbliche amministrazioni, non abbia predisposto il sistema di valutazione di cui al Titolo II del citato decreto legislativo.».

### Art. 46. - Modifiche all'articolo 28 del decreto legislativo 30 marzo 2001, n. 165

1. All'articolo 28 del decreto legislativo 30 marzo 2001, n. 165, sono apportate le seguenti modificazioni:

- a) la rubrica e' sostituita dalla seguente: "Accesso alla qualifica di dirigente della seconda fascia";
- b) al comma 2 dopo le parole: "o se in possesso del" sono inserite le seguenti: "dottorato di ricerca o del". --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'errata-corrige pubblicato in G.U. 10/11/2009, n. 262 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

### Art. 47. - Modifica all'articolo 28 del decreto legislativo 30 marzo 2001, n. 165

1. Dopo l'articolo 28 del decreto legislativo 30 marzo 2001, n. 165, e' inserito il seguente: «Art. 28-bis (Accesso alla qualifica di dirigente della prima fascia). - 1. Fermo restando quanto previsto dall'articolo 19, comma 4, l'accesso alla qualifica di dirigente di prima fascia nelle amministrazioni statali, anche ad ordinamento autonomo, e negli enti pubblici non economici avviene, per il cinquanta per cento dei posti, calcolati con riferimento a quelli che si rendono disponibili ogni anno per la cessazione dal servizio dei soggetti incaricati, tramite concorso pubblico per titoli ed esami indetto dalle singole amministrazioni, sulla base di criteri generali stabiliti con decreto del Presidente del Consiglio dei Ministri, previo parere della Scuola superiore della pubblica amministrazione. 2. Nei casi in cui lo svolgimento dei relativi incarichi richieda specifica esperienza e peculiare professionalita', alla copertura di singoli posti e comunque di una quota non superiore alla meta' di quelli da mettere a concorso ai sensi del comma 1 si puo' provvedere, con contratti di diritto privato a tempo determinato, attraverso concorso pubblico aperto ai soggetti in possesso dei requisiti professionali e delle attitudini manageriali corrispondenti al posto di funzione da coprire. I contratti sono stipulati per un periodo non superiore a tre anni. 3. Al concorso per titoli ed esami di cui al comma 1 possono essere ammessi i dirigenti di ruolo delle pubbliche amministrazioni, che abbiano maturato almeno cinque anni di servizio nei ruoli dirigenziali e gli altri soggetti in possesso di titoli di studio e professionali individuati nei bandi di concorso, con riferimento alle specifiche esigenze dell'Amministrazione e sulla base di criteri generali di equivalenza stabiliti con decreto del Presidente del Consiglio dei Ministri, previo parere della Scuola superiore della pubblica amministrazione, sentito il Ministro dell'istruzione, dell'universita' e della ricerca. A tale fine le amministrazioni che bandiscono il concorso tengono in particolare conto del personale di ruolo che ha esercitato per almeno cinque anni funzioni di livello dirigenziale generale all'interno delle stesse ovvero del personale appartenente all'organico dell'Unione europea in virtu' di un pubblico concorso organizzato da dette istituzioni. 4. I vincitori del concorso di cui al comma 1 sono assunti dall'amministrazione e, anteriormente al conferimento dell'incarico, sono tenuti all'espletamento di un periodo di formazione presso uffici amministrativi di uno Stato dell'Unione europea o di un organismo comunitario o internazionale. In ogni caso il periodo di formazione e' completato entro tre anni dalla conclusione del concorso. 5. La frequenza del periodo di formazione e' obbligatoria ed e' a tempo pieno, per una durata pari a sei mesi, anche non continuativi, e si svolge presso gli uffici di cui al comma 4, scelti dal vincitore tra quelli indicati dall'amministrazione. 6. Con regolamento emanato ai sensi dell'articolo 17, comma 1, della legge 23 agosto 1988, n. 400, su proposta del Ministro per la pubblica amministrazione e l'innovazione, di concerto con il Ministro dell'economia e delle finanze, e sentita la Scuola superiore della pubblica amministrazione, sono disciplinate le modalita' di compimento del periodo di formazione, tenuto anche conto di quanto previsto nell'articolo 32. 7. Al termine del periodo di formazione e' prevista, da parte degli uffici di cui al comma 4, una valutazione del livello di professionalita' acquisito che equivale al superamento del periodo di prova necessario per l'immissione in ruolo di cui all'articolo 70, comma 13. 8. Le spese sostenute per l'espletamento del periodo di formazione svolto presso le sedi estere di cui al comma 4 sono a carico delle singole amministrazioni nell'ambito delle risorse finanziarie disponibili a legislazione vigente.».

## Uffici, piante organiche, mobilita' e accessi

### Art. 48. - Mobilita' intercompartimentale

1. Dopo l'articolo 29 del decreto legislativo 30 marzo 2001, n. 165, nel Capo III, e' inserito il seguente: «Art. 29-bis (Mobilita' intercompartimentale). - 1. Al fine di favorire i processi di mobilita' fra i comparti di contrattazione del personale delle pubbliche amministrazioni, con decreto del Presidente del Consiglio dei Ministri, su proposta del Ministro per la pubblica amministrazione e l'innovazione, di concerto con il Ministro dell'economia e delle finanze, previo parere della Conferenza unificata di cui all'articolo 8 del decreto legislativo n. 281 del 1997, sentite le Organizzazioni sindacali e' definita, senza nuovi o maggiori oneri per la finanza pubblica, una tabella di equiparazione fra i livelli di inquadramento previsti dai contratti collettivi relativi ai diversi comparti di contrattazione.».

### Art. 49. - Modifiche all'articolo 30 del decreto legislativo 30 marzo 2001, n. 165.

1. Il comma 1 dell'articolo 30 del decreto legislativo 30 marzo 2001, n. 165, e' sostituito dal seguente: "1. Le amministrazioni possono ricoprire posti vacanti in organico mediante cessione del contratto di lavoro di dipendenti appartenenti alla stessa qualifica in servizio presso altre amministrazioni, che facciano domanda di trasferimento. Le amministrazioni devono in ogni caso rendere pubbliche le disponibilita' dei posti in organico da ricoprire attraverso passaggio diretto di personale da altre amministrazioni, fissando preventivamente i criteri di scelta. Il trasferimento e' disposto previo parere favorevole dei dirigenti responsabili dei servizi e degli uffici cui il personale e' o sara' assegnato sulla base della professionalita' in possesso del dipendente in relazione al posto ricoperto o da ricoprire.".

2. Dopo il comma 1 dell'articolo 30 del citato decreto legislativo n. 165 del 2001, e' inserito il seguente: "1-bis. Fermo restando quanto previsto al comma 2, con decreto del Ministro per la pubblica amministrazione e l'innovazione, di concerto con il Ministro dell'economia e delle finanze e previa intesa con la conferenza unificata, sentite le confederazioni sindacali rappresentative, sono disposte le misure per agevolare i processi di mobilita', anche volontaria, per garantire l'esercizio delle funzioni istituzionali da parte delle amministrazioni che presentano carenze di organico.". --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'errata-corrige pubblicato in G.U. 10/11/2009, n. 262 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

### Art. 50. - Modifica all'articolo 33 del decreto legislativo 30 marzo 2001, n. 165

1. All'articolo 33 del decreto legislativo 30 marzo 2001, n. 165, dopo il comma 1 e' inserito il seguente: «1-bis. La mancata individuazione da parte del dirigente responsabile delle eccedenze delle unita' di personale, ai sensi del comma 1, e' valutabile ai fini della responsabilita' per danno erariale.».

### Art. 51. - Territorializzazione delle procedure concorsuali

1. All'articolo 35 del decreto legislativo 30 marzo 2001, n. 165, al comma 5-ter e' aggiunto, in fine, il seguente periodo: «Il principio della parita' di condizioni per l'accesso ai pubblici uffici e' garantito, mediante specifiche disposizioni del bando, con riferimento al luogo di residenza dei concorrenti, quando tale requisito sia strumentale all'assolvimento di servizi altrimenti non attuabili o almeno non attuabili con identico risultato.».

### Art. 52. - Modifiche all'articolo 53 del decreto legislativo 30 marzo 2001, n. 165

1. All'articolo 53 del decreto legislativo 30 marzo 2001, n. 165, sono apportate le seguenti modificazioni:

- a) dopo il comma 1, e' inserito il seguente: "1-bis. Non possono essere conferiti incarichi di direzione di strutture deputate alla gestione del personale a soggetti che rivestano o abbiano rivestito negli ultimi due anni cariche in partiti politici o in organizzazioni sindacali o che abbiano avuto negli ultimi due anni rapporti continuativi di collaborazione o di consulenza con le predette organizzazioni.";
- b) il comma 16-bis e' sostituto dal seguente: "16-bis. La Presidenza del Consiglio dei Ministri - Dipartimento della funzione pubblica puo' disporre verifiche del rispetto delle disposizioni del presente articolo e dell' articolo 1, commi 56 e seguenti, della legge 23 dicembre 1996, n. 662, per il tramite dell'Ispettorato per la funzione pubblica. A tale fine quest'ultimo opera d'intesa con i Servizi ispettivi di finanza pubblica del Dipartimento della Ragioneria generale dello Stato.". --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'errata-corrige pubblicato in G.U. 10/11/2009, n. 262 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

## Contrattazione collettiva nazionale e integrativa

### Art. 53. - Oggetto, ambito di applicazione e finalita'

1. Il presente capo reca disposizioni in materia di contrattazione collettiva e integrativa e di funzionalita' delle amministrazioni pubbliche, al fine di conseguire, in coerenza con il modello contrattuale sottoscritto dalle parti sociali, una migliore organizzazione del lavoro e di assicurare il rispetto della ripartizione tra le materie sottoposte alla legge, nonche', sulla base di questa, ad atti organizzativi e all'autonoma determinazione dei dirigenti, e quelle sottoposte alla contrattazione collettiva.

### Art. 54. - Modifiche all'articolo 40 del decreto legislativo 30 marzo 2001, n. 165

1. All'articolo 40 del decreto legislativo n. 165 del 2001, i commi da 1 a 3 sono sostituiti dai seguenti: «1. La contrattazione collettiva determina i diritti e gli obblighi direttamente pertinenti al rapporto di lavoro, nonche' le materie relative alle relazioni sindacali. Sono, in particolare, escluse dalla contrattazione collettiva le materie attinenti all'organizzazione degli uffici, quelle oggetto di partecipazione sindacale ai sensi dell'articolo 9, quelle afferenti alle prerogative dirigenziali ai sensi degli articoli 5, comma 2, 16 e 17, la materia del conferimento e della revoca degli incarichi dirigenziali, nonche' quelle di cui all'articolo 2, comma 1, lettera c), della legge 23 ottobre 1992, n. 421. Nelle materie relative alle sanzioni disciplinari, alla valutazione delle prestazioni ai fini della corresponsione del trattamento accessorio, della mobilita' e delle progressioni economiche, la contrattazione collettiva e' consentita negli esclusivi limiti previsti dalle norme di legge. 2. Tramite appositi accordi tra l'ARAN e le Confederazioni rappresentative, secondo le procedure di cui agli articoli 41, comma 5, e 47, senza nuovi o maggiori oneri per la finanza pubblica, sono definiti fino a un massimo di quattro comparti di contrattazione collettiva nazionale, cui corrispondono non piu' di quattro separate aree per la dirigenza.Una apposita sezione contrattuale di un'area dirigenziale riguarda la dirigenza del ruolo sanitario del Servizio sanitario nazionale, per gli effetti di cui all'articolo 15 del decreto legislativo 30 dicembre 1992, n. 502, e successive modificazioni. Nell'ambito dei comparti di contrattazione possono essere costituite apposite sezioni contrattuali per specifiche professionalita'. 3. La contrattazione collettiva disciplina, in coerenza con il settore privato, la struttura contrattuale, i rapporti tra i diversi livelli e la durata dei contratti collettivi nazionali e integrativi. La durata viene stabilita in modo che vi sia coincidenza fra la vigenza della disciplina giuridica e di quella economica. 3-bis. Le pubbliche amministrazioni attivano autonomi livelli di contrattazione collettiva integrativa, nel rispetto dell'articolo 7, comma 5, e dei vincoli di bilancio risultanti dagli strumenti di programmazione annuale e pluriennale di ciascuna amministrazione. La contrattazione collettiva integrativa assicura adeguati livelli di efficienza e produttivita' dei servizi pubblici, incentivando l'impegno e la qualita' della performance ai sensi dell'articolo 45, comma 3. A tale fine destina al trattamento economico accessorio collegato alla performance individuale una quota prevalente del trattamento accessorio complessivo comunque denominato Essa si svolge sulle materie, con i vincoli e nei limiti stabiliti dai contratti collettivi nazionali, tra i soggetti e con le procedure negoziali che questi ultimi prevedono; essa puo' avere ambito territoriale e riguardare piu' amministrazioni. I contratti collettivi nazionali definiscono il termine delle sessioni negoziali in sede decentrata. Alla scadenza del termine le parti riassumono le rispettive prerogative e liberta' di iniziativa e decisione. 3-ter. Al fine di assicurare la continuita' e il migliore svolgimento della funzione pubblica, qualora non si raggiunga l'accordo per la stipulazione di un contratto collettivo integrativo, l'amministrazione interessata puo' provvedere, in via provvisoria, sulle materie oggetto del mancato accordo, fino alla successiva sottoscrizione. Agli atti adottati unilateralmente si applicano le procedure di controllo di compatibilita' economico-finanziaria previste dall'articolo 40-bis. 3-quater. La Commissione di cui all'articolo 13 del decreto legislativo di attuazione della legge 4 marzo 2009, n. 15, in materia di ottimizzazione della produttivita' del lavoro pubblico e di efficienza e trasparenza delle pubbliche amministrazioni, fornisce, entro il 31 maggio di ogni anno, all'ARAN una graduatoria di performance delle amministrazioni statali e degli enti pubblici nazionali. Tale graduatoria raggruppa le singole amministrazioni, per settori, su almeno tre livelli di merito, in funzione dei risultati di performance ottenuti. La contrattazione nazionale definisce le modalita' di ripartizione delle risorse per la contrattazione decentrata tra i diversi livelli di merito assicurando l'invarianza complessiva dei relativi oneri nel comparto o nell'area di contrattazione. 3-quinquies. La contrattazione collettiva nazionale dispone, per le amministrazioni di cui al comma 3 dell'articolo 41, le modalita' di utilizzo delle risorse indicate all'articolo 45, comma 3-bis, individuando i criteri e i limiti finanziari entro i quali si deve svolgere la contrattazione integrativa. Le regioni, per quanto concerne le proprie amministrazioni, e gli enti locali possono destinare risorse aggiuntive alla contrattazione integrativa nei limiti stabiliti dalla contrattazione nazionale e nei limiti dei parametri di virtuosita' fissati per la spesa di personale dalle vigenti disposizioni, in ogni caso nel rispetto dei vincoli di bilancio e del patto di stabilita' e di analoghi strumenti del contenimento della spesa. Lo stanziamento delle risorse aggiuntive per la contrattazione integrativa e' correlato all'affettivo rispetto dei principi in materia di misurazione, valutazione e trasparenza della performance e in materia di merito e premi applicabili alle regioni e agli enti locali secondo quanto previsto dagli articoli 16 e 31 del decreto legislativo di attuazione della legge 4 marzo 2009, n. 15, in materia di ottimizzazione della produttivita' del lavoro pubblico e di efficienza e trasparenza delle pubbliche amministrazioni. Le pubbliche amministrazioni non possono in ogni caso sottoscrivere in sede decentrata contratti collettivi integrativi in contrasto con i vincoli e con i limiti risultanti dai contratti collettivi nazionali o che disciplinano materie non espressamente delegate a tale livello negoziale ovvero che comportano oneri non previsti negli strumenti di programmazione annuale e pluriennale di ciascuna amministrazione. Nei casi di violazione dei vincoli e dei limiti di competenza imposti dalla contrattazione nazionale o dalle norme di legge, le clausole sono nulle, non possono essere applicate e sono sostituite ai sensi degli articoli 1339 e 1419, secondo comma, del codice civile. In caso di accertato superamento di vincoli finanziari da parte delle sezioni regionali di controllo della Corte dei conti, del Dipartimento della funzione pubblica o del Ministero dell'economia e delle finanze e' fatto altresi' obbligo di recupero nell'ambito della sessione negoziale successiva. Le disposizioni del presente comma trovano applicazione a decorrere dai contratti sottoscritti successivamente alla data di entrata in vigore del decreto legislativo di attuazione della legge 4 marzo 2009, n. 15, in materia di ottimizzazione della produttivita' del lavoro pubblico e di efficienza e trasparenza delle pubbliche amministrazioni. 3-sexies. A corredo di ogni contratto integrativo le pubbliche amministrazioni, redigono una relazione tecnico-finanziaria ed una relazione illustrativa, utilizzando gli schemi appositamente predisposti e resi disponibili tramite i rispettivi siti istituzionalidal Ministero dell'economia e delle finanze di intesa con il Dipartimento della funzione pubblica. Tali relazioni vengono certificate dagli organi di controllo di cui all'articolo 40-bis, comma 1.».

### Art. 55. - Modifica all'articolo 40-bis del decreto legislativo 30 marzo 2001, n. 165

1. L'articolo 40-bis del decreto legislativo 30 marzo 2001, n. 165, e' sostituito dal seguente: «Art. 40-bis (Controlli in materia di contrattazione integrativa). - 1. Il controllo sulla compatibilita' dei costi della contrattazione collettiva integrativa con i vincoli di bilancio e quelli derivanti dall'applicazione delle norme di legge, con particolare riferimento alle disposizioni inderogabili che incidono sulla misura e sulla corresponsione dei trattamenti accessori e' effettuato dal collegio dei revisori dei conti, dal collegio sindacale, dagli uffici centrali di bilancio o dagli analoghi organi previsti dai rispettivi ordinamenti. Qualora dai contratti integrativi derivino costi non compatibili con i rispettivi vincoli di bilancio delle amministrazioni, si applicano le disposizioni di cui all'articolo 40, comma 3-quinquies, sesto periodo. 2. Per le amministrazioni statali, anche ad ordinamento autonomo, nonche' per gli enti pubblici non economici e per gli enti e le istituzioni di ricerca con organico superiore a duecento unita', i contratti integrativi sottoscritti, corredati da una apposita relazione tecnico-finanziaria ed una relazione illustrativa certificate dai competenti organi di controllo previsti dal comma 1, sono trasmessi alla Presidenza del Consiglio dei Ministri - Dipartimento della funzione pubblica e al Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato, che, entro trenta giorni dalla data di ricevimento, ne accertano, congiuntamente, la compatibilita' economico-finanziaria, ai sensi del presente articolo e dell'articolo 40, comma 3-quinquies. Decorso tale termine, che puo' essere sospeso in caso di richiesta di elementi istruttori, la delegazione di parte pubblica puo' procedere alla stipula del contratto integrativo. Nel caso in cui il riscontro abbia esito negativo, le parti riprendono le trattative. 3. Le amministrazioni pubbliche di cui all'articolo 1, comma 2, inviano entro il 31 maggio di ogni anno, specifiche informazioni sui costi della contrattazione integrativa, certificate dagli organi di controllo interno, al Ministero dell'economia e delle finanze, che predispone, allo scopo, uno specifico modello di rilevazione, d'intesa con la Corte dei conti e con la Presidenza del Consiglio dei Ministri - Dipartimento della funzione pubblica. Tali informazioni sono volte ad accertare, oltre il rispetto dei vincoli finanziari in ordine sia alla consistenza delle risorse assegnate ai fondi per la contrattazione integrativa sia all'evoluzione della consistenza dei fondi e della spesa derivante dai contratti integrativi applicati, anche la concreta definizione ed applicazione di criteri improntati alla premialita', al riconoscimento del merito ed alla valorizzazione dell'impegno e della qualita' della performanceindividuale, con riguardo ai diversi istituti finanziati dalla contrattazione integrativa, nonche' a parametri di selettivita', con particolare riferimento alle progressioni economiche. Le informazioni sono trasmesse alla Corte dei conti che, ferme restando le ipotesi di responsabilita' eventualmente ravvisabili le utilizza, unitamente a quelle trasmesse ai sensi del Titolo V, anche ai fini del referto sul costo del lavoro. 4. Le amministrazioni pubbliche hanno l'obbligo di pubblicare in modo permanente sul proprio sito istituzionale, con modalita' che garantiscano la piena visibilita' e accessibilita' delle informazioni ai cittadini, i contratti integrativi stipulati con la relazione tecnico-finanziaria e quella illustrativa certificate dagli organi di controllo di cui al comma 1, nonche' le informazioni trasmesse annualmente ai sensi del comma 3. La relazione illustrativa, fra l'altro, evidenzia gli effetti attesi in esito alla sottoscrizione del contratto integrativo in materia di produttivita' ed efficienza dei servizi erogati, anche in relazione alle richieste dei cittadini. Il Dipartimento per la funzione pubblica di intesa con il Ministero dell'economia e delle finanze e in sede di Conferenza unificata predispone un modello per la valutazione, da parte dell'utenza, dell'impatto della contrattazione integrativa sul funzionamento dei servizi pubblici, evidenziando le richieste e le previsioni di interesse per la collettivita'. Tale modello e gli esiti della valutazione vengono pubblicati sul sito istituzionale delle amministrazioni pubbliche interessate dalla contrattazione integrativa. 5. Ai fini dell'articolo 46, comma 4, le pubbliche amministrazioni sono tenute a trasmettere all'ARAN, per via telematica, entro cinque giorni dalla sottoscrizione, il testo contrattuale con l'allegata relazione tecnico-finanziaria ed illustrativa e con l'indicazione delle modalita' di copertura dei relativi oneri con riferimento agli strumenti annuali e pluriennali di bilancio. I predetti testi contrattuali sono altresi' trasmessi al CNEL. 6. Il Dipartimento della funzione pubblica, il Dipartimento della Ragioneria generale dello Stato presso il Ministero dell'economia e delle finanze e la Corte dei conti possono avvalersi ai sensi dell'articolo 17, comma 14, della legge 15 maggio 1997, n. 127, di personale in posizione di fuori ruolo o di comando per l'esercizio delle funzioni di controllo sulla contrattazione integrativa. 7. In caso di mancato adempimento delle prescrizioni del presente articolo, oltre alle sanzioni previste dall'articolo 60, comma 2, e' fatto divieto alle amministrazioni di procedere a qualsiasi adeguamento delle risorse destinate alla contrattazione integrativa. Gli organi di controllo previsti dal comma 1 vigilano sulla corretta applicazione delle disposizioni del presente articolo.».

### Art. 56. - Modifica all'articolo 41 del decreto legislativo 30 marzo 2001, n. 165

1. L'articolo 41 del decreto legislativo 30 marzo 2001, n. 165, e' sostituito dal seguente: «Art. 41 (Poteri di indirizzo nei confronti dell'ARAN). - 1. Il potere di indirizzo nei confronti dell'ARAN e le altre competenze relative alle procedure di contrattazione collettiva nazionale sono esercitati dalle pubbliche amministrazioni attraverso le proprie istanze associative o rappresentative, le quali costituiscono comitati di settore che regolano autonomamente le proprie modalita' di funzionamento e di deliberazione. In ogni caso, le deliberazioni assunte in materia di indirizzo all'ARAN o di parere sull'ipotesi di accordo nell'ambito della procedura di contrattazione collettiva di cui all'articolo 47, si considerano definitive e non richiedono ratifica da parte delle istanze associative o rappresentative delle pubbliche amministrazioni del comparto. 2. E' costituito un comitato di settore nell'ambito della Conferenza delle Regioni, che esercita, per uno dei comparti di cui all'articolo 40, comma 2, le competenze di cui al comma 1, per le regioni, i relativi enti dipendenti, e le amministrazioni del Servizio sanitario nazionale; a tale comitato partecipa un rappresentante del Governo, designato dal Ministro del lavoro, della salute e delle politiche sociali per le competenze delle amministrazioni del Servizio sanitario nazionale. E' costituito un comitato di settore nell'ambito dell'Associazione nazionale dei Comuni italiani (ANCI), dell'Unione delle province d'Italia (UPI) e dell'Unioncamere che esercita, per uno dei comparti di cui all'articolo 40, comma 2, le competenze di cui al comma 1, per i dipendenti degli enti locali, delle Camere di commercio e dei segretari comunali e provinciali. 3. Per tutte le altre amministrazioni opera come comitato di settore il Presidente del Consiglio dei Ministri tramite il Ministro per la pubblica amministrazione e l'innovazione, di concerto con il Ministro dell'economia e finanze. Al fine di assicurare la salvaguardia delle specificita' delle diverse amministrazioni e delle categorie di personale ivi comprese, gli indirizzi sono emanati per il sistema scolastico, sentito il Ministro dell'istruzione, dell'universita' e della ricerca, nonche', per i rispettivi ambiti di competenza, sentiti i direttori delle Agenzie fiscali, la Conferenza dei rettori delle universita' italiane; le istanze rappresentative promosse dai presidenti degli enti di ricerca e degli enti pubblici non economici ed il presidente del Consiglio nazionale dell'economia e del lavoro. 4. Rappresentati designati dai Comitati di settore possono assistere l'ARAN nello svolgimento delle trattative. I comitati di settore possono stipulare con l'ARAN specifici accordi per i reciproci rapporti in materia di contrattazione e per eventuali attivita' in comune. Nell'ambito del regolamento di organizzazione dell'ARAN per assicurare il miglior raccordo tra i Comitati di settore delle Regioni e degli enti locali e l'ARAN, a ciascun comitato corrisponde una specifica struttura, senza nuovi o maggiori oneri per la finanza pubblica. 5. Per la stipulazione degli accordi che definiscono o modificano i comparti o le aree di contrattazione collettiva di cui all'articolo 40, comma 2, o che regolano istituti comuni a piu' comparti le funzioni di indirizzo e le altre competenze inerenti alla contrattazione collettiva sono esercitate collegialmente dai comitati di settore.».

### Art. 57. - Modifica all'articolo 45 del decreto legislativo 30 marzo 2001, n. 165

1. All'articolo 45, comma 1, del decreto legislativo 30 marzo 2001, n. 165, sono apportate le seguenti modificazioni:

- a) al comma 1, dopo le parole: «fondamentale ed accessorio» sono inserite le seguenti: «fatto salvo quanto previsto all'articolo 40, commi 3-ter e 3-quater, e all'articolo 47-bis, comma 1,»;
- b) il comma 3 e' sostituito dal seguente: «3. I contratti collettivi definiscono, in coerenza con le disposizioni legislative vigenti, trattamenti economici accessori collegati: a) alla performance individuale; b) alla performance organizzativa con riferimento all'amministrazione nel suo complesso e alle unita' organizzative o aree di responsabilita' in cui si articola l'amministrazione; c) all'effettivo svolgimento di attivita' particolarmente disagiate ovvero pericolose o dannose per la salute.»;
- c) dopo il comma 3 e' inserito il seguente: «3-bis. Per premiare il merito e il miglioramento della performance dei dipendenti, ai sensi delle vigenti disposizioni di legge, sono destinate, compatibilmente con i vincoli di finanza pubblica, apposite risorse nell'ambito di quelle previste per il rinnovo del contratto collettivo nazionale di lavoro.».

### Art. 58. - Modifiche all'articolo 46 del decreto legislativo 30 marzo 2001, n. 165

1. All'articolo 46 del decreto legislativo 30 marzo 2001, n. 165, sono apportate le seguenti modificazioni:

- a) i commi da 3 a 7 sono sostituiti dai seguenti: «3. L'ARAN cura le attivita' di studio, monitoraggio e documentazione necessarie all'esercizio della contrattazione collettiva. Predispone a cadenza semestrale, ed invia al Governo, ai comitati di settore dei comparti regioni e autonomie locali e sanita' e alle commissioni parlamentari competenti, un rapporto sull'evoluzione delle retribuzioni di fatto dei pubblici dipendenti. A tale fine l'ARAN si avvale della collaborazione dell'ISTAT per l'acquisizione di informazioni statistiche e per la formulazione di modelli statistici di rilevazione. L'ARAN si avvale, altresi', della collaborazione del Ministero dell'economia e delle finanze che garantisce l'accesso ai dati raccolti in sede di predisposizione del bilancio dello Stato, del conto annuale del personale e del monitoraggio dei flussi di cassa e relativi agli aspetti riguardanti il costo del lavoro pubblico. 4. L'ARAN effettua il monitoraggio sull'applicazione dei contratti collettivi nazionali e sulla contrattazione collettiva integrativa e presenta annualmente al Dipartimento della funzione pubblica, al Ministero dell'economia e delle finanze nonche' ai comitati di settore, un rapporto in cui verifica l'effettivita' e la congruenza della ripartizione fra le materie regolate dalla legge, quelle di competenza della contrattazione nazionale e quelle di competenza dei contratti integrativi nonche' le principali criticita' emerse in sede di contrattazione collettiva nazionale ed integrativa. 5. Sono organi dell'ARAN: a) il Presidente; b) il Collegio di indirizzo e controllo. 6. Il Presidente dell'ARAN e' nominato con decreto del Presidente della Repubblica, su proposta del Ministro per la pubblica amministrazione e l'innovazione previo parere della Conferenza unificata. Il Presidente rappresenta l'agenzia ed e' scelto fra esperti in materia di economia del lavoro, diritto del lavoro, politiche del personale e strategia aziendale, anche estranei alla pubblica amministrazione, nel rispetto delle disposizioni riguardanti le incompatibilita' di cui al comma 7-bis. Il Presidente dura in carica quattro anni e puo' essere riconfermato per una sola volta. La carica di Presidente e' incompatibile con qualsiasi altra attivita' professionale a carattere continuativo, se dipendente pubblico, e' collocato in aspettativa o in posizione di fuori ruolo secondo l'ordinamento dell'amministrazione di appartenenza. 7. Il collegio di indirizzo e controllo e' costituito da quattro componenti scelti tra esperti di riconosciuta competenza in materia di relazioni sindacali e di gestione del personale, anche estranei alla pubblica amministrazione e dal presidente dell'Agenzia che lo presiede; due di essi sono designati con decreto del Presidente del Consiglio dei Ministri, su proposta, rispettivamente, del Ministro per la pubblica amministrazione e l'innovazione e del Ministro dell'economia e delle finanze e gli altri due, rispettivamente, dall'ANCI e dall'UPI e dalla Conferenza delle Regioni e delle province autonome. Il collegio coordina la strategia negoziale e ne assicura l'omogeneita', assumendo la responsabilita' per la contrattazione collettiva e verificando che le trattative si svolgano in coerenza con le direttive contenute negli atti di indirizzo. Nell'esercizio delle sue funzioni il collegio delibera a maggioranza, su proposta del presidente. Il collegio dura in carica quattro anni e i suoi componenti possono essere riconfermati per una sola volta.»;
- b) dopo il comma 7 e' inserito il seguente: «7-bis. Non possono far parte del collegio di indirizzo e controllo ne' ricoprire funzioni di presidente, persone che rivestano incarichi pubblici elettivi o cariche in partiti politici ovvero che ricoprano o abbiano ricoperto nei cinque anni precedenti alla nomina cariche in organizzazioni sindacali. L'incompatibilita' si intende estesa a qualsiasi rapporto di carattere professionale o di consulenza con le predette organizzazioni sindacali o politiche. L'assenza delle predette cause di incompatibilita' costituisce presupposto necessario per l'affidamento degli incarichi dirigenziali nell'agenzia.»;
- c) al comma 8, lettera a), il secondo periodo e' sostituito dal seguente: «La misura annua del contributo individuale e' definita, sentita l'ARAN, con decreto del Ministro dell'economia e delle finanze, di concerto con il Ministro della pubblica amministrazione e l'innovazione, d'intesa con la Conferenza unificata ed e' riferita a ciascun triennio contrattuale; »;
- d) al comma 9, la lettera a) e' sostituita dalla seguente: «a) per le amministrazioni dello Stato mediante l'assegnazione di risorse pari all'ammontare dei contributi che si prevedono dovuti nell'esercizio di riferimento. L'assegnazione e' effettuata annualmente sulla base della quota definita al comma 8, lettera a), con la legge annuale di bilancio, con imputazione alla pertinente unita' previsionale di base dello stato di previsione del ministero dell'economia e finanze; »;
- e) al comma 10, nel quinto periodo, le parole: «quindici giorni» sono sostituite dalle seguenti: «quarantacinque giorni» e dopo le parole: «Dipartimento della funzione pubblica» sono inserite le seguenti: «e del Ministero dell'economia e delle finanze, adottati d'intesa con la Conferenza unificata,»;
- f) al comma 11, il primo periodo e' sostituito dal seguente: «Il ruolo del personale dipendente dell'ARAN e' definito in base ai regolamenti di cui al comma 10»;
- g) al comma 12: 1) il primo periodo e' sostituito dal seguente: «L'ARAN puo' altresi' avvalersi di un contingente di personale, anche di qualifica dirigenziale, proveniente dalle pubbliche amministrazioni rappresentate, in posizione di comando o fuori ruolo in base ai regolamenti di cui al comma 10»; 2) l'ultimo periodo e' sostituito dal seguente: «L'ARAN puo' avvalersi di esperti e collaboratori esterni con modalita' di rapporto stabilite con i regolamenti adottati ai sensi del comma 10, nel rispetto dell'articolo 7, commi 6 e seguenti.».

2. Entro trenta giorni dalla data di entrata in vigore del presente decreto si provvede alla nomina dei nuovi organi dell'ARAN di cui all'articolo 46, comma 5, del decreto legislativo 30 marzo 2001, n. 165, come modificato dal comma 1. Fino alla nomina dei nuovi organi, e comunque non oltre il termine di cui al precedente periodo, continuano ad operare gli organi in carica alla data di entrata in vigore del presente decreto.

### Art. 59. - Modifiche all'articolo 47 del decreto legislativo 30 marzo 2001, n. 165

1. L'articolo 47 del decreto legislativo 30 marzo 2001, n. 165, e' sostituito dal seguente: «Art. 47 (Procedimento di contrattazione collettiva). - 1. Gli indirizzi per la contrattazione collettiva nazionale sono emanati dai Comitati di settore prima di ogni rinnovo contrattuale. 2. Gli atti di indirizzo delle amministrazioni di cui all'articolo 41, comma 2, emanati dai rispettivi comitati di settore, sono sottoposti al Governo che, nei successivi venti giorni, puo' esprimere le sue valutazioni per quanto attiene agli aspetti riguardanti la compatibilita' con le linee di politica economica e finanziaria nazionale. Trascorso inutilmente tale termine l'atto di indirizzo puo' essere inviato all'ARAN. 3. Sono altresi' inviati appositi atti di indirizzo all'ARAN in tutti gli altri casi in cui e' richiesta una attivita' negoziale. L'ARAN informa costantemente i comitati di settore e il Governo sullo svolgimento delle trattative. 4. L'ipotesi di accordo e' trasmessa dall'ARAN, corredata dalla prescritta relazione tecnica, ai comitati di settore ed al Governo entro 10 giorni dalla data di sottoscrizione. Per le amministrazioni di cui all'articolo 41, comma 2, il comitato di settore esprime il parere sul testo contrattuale e sugli oneri finanziari diretti e indiretti a carico dei bilanci delle amministrazioni interessate.Fino alla data di entrata in vigore dei decreti di attuazione della legge 5 maggio 2009, n. 42, il Consiglio dei Ministri puo' esprimere osservazioni entro 20 giorni dall'invio del contratto da parte dell'ARAN. Per le amministrazioni di cui al comma 3 del medesimo articolo 41, il parere e' espresso dal Presidente del Consiglio dei Ministri, tramite il Ministro per la pubblica amministrazione e l'innovazione, previa deliberazione del Consiglio dei Ministri. 5. Acquisito il parere favorevole sull'ipotesi di accordo, nonche' la verifica da parte delle amministrazioni interessate sulla copertura degli oneri contrattuali, il giorno successivo l'ARAN trasmette la quantificazione dei costi contrattuali alla Corte dei conti ai fini della certificazione di compatibilita' con gli strumenti di programmazione e di bilancio di cui all'articolo 1-bis della legge 5 agosto 1978, n. 468, e successive modificazioni. La Corte dei conti certifica l'attendibilita' dei costi quantificati e la loro compatibilita' con gli strumenti di programmazione e di bilancio. La Corte dei conti delibera entro quindici giorni dalla trasmissione della quantificazione dei costi contrattuali, decorsi i quali la certificazione si intende effettuata positivamente. L'esito della certificazione viene comunicato dalla Corte all'ARAN, al comitato di settore e al Governo. Se la certificazione e' positiva, il presidente dell'ARAN sottoscrive definitivamente il contratto collettivo. 6. La Corte dei conti puo' acquisire elementi istruttori e valutazioni sul contratto collettivo da parte di tre esperti in materia di relazioni sindacali e costo del lavoro individuati dal Ministro per la pubblica amministrazione e l'innovazione, tramite il Capo del Dipartimento della funzione pubblica di intesa con il Capo del Dipartimento della Ragioneria generale dello Stato, nell'ambito di un elenco definito di concerto con il Ministro dell'economia e delle finanze. Nel caso delle amministrazioni di cui all'articolo 41, comma 2, la designazione di due esperti viene effettuata dall'ANCI, dall' UPI e dalla Conferenza delle Regioni e delle province autonome. 7. In caso di certificazione non positiva della Corte dei conti le parti contraenti non possono procedere alla sottoscrizione definitiva dell'ipotesi di accordo. Nella predetta ipotesi, il Presidente dell'ARAN, d'intesa con il competente comitato di settore, che puo' dettare indirizzi aggiuntivi, provvede alla riapertura delle trattative ed alla sottoscrizione di una nuova ipotesi di accordo adeguando i costi contrattuali ai fini delle certificazioni. In seguito alla sottoscrizione della nuova ipotesi di accordo si riapre la procedura di certificazione prevista dai commi precedenti. Nel caso in cui la certificazione non positiva sia limitata a singole clausole contrattuali l'ipotesi puo' essere sottoscritta definitivamente ferma restando l'inefficacia delle clausole contrattuali non positivamente certificate. 8. I contratti e accordi collettivi nazionali, nonche' le eventuali interpretazioni autentiche sono pubblicati nella Gazzetta Ufficiale della Repubblica italiana oltre che sul sito dell'ARAN e delle amministrazioni interessate. 9. Dal computo dei termini previsti dal presente articolo sono esclusi i giorni considerati festivi per legge, nonche' il sabato.».

2. Dopo l'articolo 47 del decreto legislativo 30 marzo 2001, n. 165, e' inserito il seguente: «Art. 47-bis (Tutela retributiva per i dipendenti pubblici.). - 1. Decorsi sessanta giorni dalla data di entrata in vigore della legge finanziaria che dispone in materia di rinnovi dei contratti collettivi per il periodo di riferimento, gli incrementi previsti per il trattamento stipendiale possono essere erogati in via provvisoria previa deliberazione dei rispettivi comitati di settore, sentite le organizzazioni sindacali rappresentative. salvo conguaglio all'atto della stipulazione dei contratti collettivi nazionali di lavoro. 2. In ogni caso a decorrere dal mese di aprile dell'anno successivo alla scadenza del contratto collettivo nazionale di lavoro, qualora lo stesso non sia ancora stato rinnovato e non sia stata disposta l'erogazione di cui al comma 1, e' riconosciuta ai dipendenti dei rispettivi comparti di contrattazione, nella misura e con le modalita' stabilite dai contratti nazionali, e comunque entro i limiti previsti dalla legge finanziaria in sede di definizione delle risorse contrattuali,una copertura economica che costituisce un'anticipazione dei benefici complessivi che saranno attribuiti all'atto del rinnovo contrattuale.».

### Art. 60. - Modifiche all'articolo 48 del decreto legislativo 30 marzo 2001, n. 165

1. All'articolo 48 del decreto legislativo 30 marzo 2001, n. 165, sono apportate le seguenti modificazioni:

- a) al comma 1, ultimo periodo, le parole: «40, comma 3.» sono sostituite dalle seguenti: «40, comma 3 -bis.»;
- b) il comma 2 e' sostituito dal seguente: «2. Per le amministrazioni di cui all'articolo 41, comma 2, nonche' per le universita' italiane, gli enti pubblici non economici e gli enti e le istituzioni di ricerca, ivi compresi gli enti e le amministrazioni di cui all'articolo 70, comma 4, gli oneri derivanti dalla contrattazione collettiva nazionale sono determinati a carico dei rispettivi bilanci nel rispetto dell'articolo 40, comma 3-quinquies. Le risorse per gli incrementi retributivi per il rinnovo dei contratti collettivi nazionali delle amministrazioni regionali, locali e degli enti del Servizio sanitario nazionale sono definite dal Governo, nel rispetto dei vincoli di bilancio, del patto di stabilita' e di analoghi strumenti di contenimento della spesa, previa consultazione con le rispettive rappresentanze istituzionali del sistema delle autonomie.»;
- c) il comma 6 e' abrogato.

### Art. 61. - Modifica all'articolo 49 del decreto legislativo 30 marzo 2001, n. 165

1. L'articolo 49 del decreto legislativo 30 marzo 2001, n. 165, e' sostituito dal seguente: «Art. 49 (Interpretazione autentica dei contratti collettivi). - 1. Quando insorgano controversie sull'interpretazione dei contratti collettivi, le parti che li hanno sottoscritti si incontrano per definire consensualmente il significato delle clausole controverse. 2. L'eventuale accordo di interpretazione autentica, stipulato con le procedure di cui all'articolo 47, sostituisce la clausola in questione sin dall'inizio della vigenza del contratto. Qualora tale accordo non comporti oneri aggiuntivi e non vi sia divergenza sulla valutazione degli stessi, il parere del Presidente del Consiglio dei Ministri e' espresso tramite il Ministro per la pubblica amministrazione e l'innovazione, di concerto con il Ministro dell'economia e delle finanze.».

### Art. 62. - Modifiche all'articolo 52 del decreto legislativo 30 marzo 2001, n. 165

1. All'articolo 52 del decreto legislativo 30 marzo 2001, n. 165, il comma 1 e' sostituito dai seguenti: «1. Il prestatore di lavoro deve essere adibito alle mansioni per le quali e' stato assunto o alle mansioni equivalenti nell'ambito dell'area di inquadramentoovvero a quelle corrispondenti alla qualifica superiore che abbia successivamente acquisito per effetto delle procedure selettive di cui all'articolo 35, comma 1, lettera a). L'esercizio di fatto di mansioni non corrispondenti alla qualifica di appartenenza non ha effetto ai fini dell'inquadramento del lavoratore o dell'assegnazione di incarichi di direzione. 1-bis. I dipendenti pubblici, con esclusione dei dirigenti e del personale docente della scuola, delle accademie, conservatori e istituti assimilati, sono inquadrati in almeno tre distinte aree funzionali. Le progressioni all'interno della stessa area avvengono secondo principi di selettivita', in funzione delle qualita' culturali e professionali, dell'attivita' svolta e dei risultati conseguiti, attraverso l'attribuzione di fasce di merito. Le progressioni fra le aree avvengono tramite concorso pubblico, ferma restando la possibilita' per l'amministrazione di destinare al personale interno, in possesso dei titoli di studio richiesti per l'accesso dall'esterno, una riserva di posti comunque non superiore al 50 per cento di quelli messi a concorso. La valutazione positiva conseguita dal dipendente per almeno tre anni costituisce titolo rilevante ai fini della progressione economica e dell'attribuzione dei posti riservati nei concorsi per l'accesso all'area superiore. 1-ter. Per l'accesso alle posizioni economiche apicali nell'ambito delle aree funzionali e' definita una quota di accesso nel limite complessivo del 50 per cento da riservare a concorso pubblico sulla base di un corso concorso bandito dalla Scuola superiore della pubblica amministrazione.».

### Art. 63. - Procedimenti negoziali per il personale ad ordinamento pubblicistico

1. All'articolo 112 del decreto del Presidente della Repubblica 5 gennaio 1967, n. 18, al primo comma, le parole: «con cadenza quadriennale per gli aspetti giuridici e biennale per quelli economici» sono sostituite dalle seguenti: «con cadenza triennale tanto per la parte economica che normativa». Fermo quanto disposto dal primo periodo, al fine di garantire il parallelismo temporale della disciplina della carriera diplomatica rispetto a quella degli altri comparti del settore pubblico, il decreto del Presidente della Repubblica emanato in riferimento al quadriennio 2008-2011 ha durata limitata al biennio 2008-2009 anche per gli aspetti giuridici.

2. All'articolo 7 del decreto legislativo 12 maggio 1995, n. 195, il comma 12 e' sostituito dal seguente: «12. La disciplina emanata con i decreti del Presidente della Repubblica di cui al comma 11 ha durata triennale tanto per la parte economica che normativa, a decorrere dai termini di scadenza previsti dai precedenti decreti, e conserva efficacia fino alla data di entrata in vigore dei decreti successivi.».

3. All'articolo 26 del decreto legislativo 19 maggio 2000, n. 139, il comma 3 e' sostituito dal seguente: «3. La disciplina emanata con il decreto di cui al comma 2 ha durata triennale tanto per la parte economica che normativa a decorrere dal termine di scadenza previsto dal precedente decreto e conserva efficacia fino alla data di entrata in vigore del decreto successivo.».

4. All'articolo 34 del decreto legislativo 13 ottobre 2005, n. 217, il comma 2 e' sostituito dal seguente: «2. Il procedimento negoziale di cui al comma 1 si conclude con l'emanazione di un decreto del Presidente della Repubblica, la cui disciplina ha durata triennale tanto per la parte economica che normativa.».

5. All'articolo 80 del decreto legislativo 13 ottobre 2005, n. 217, il comma 2 e' sostituito dal seguente: «2. Il procedimento negoziale di cui al comma 1 si conclude con l'emanazione di un decreto del Presidente della Repubblica, la cui disciplina ha durata triennale tanto per la parte economica che normativa.».

6. Il comma 6 degli articoli 37 e 83 del decreto legislativo 13 ottobre 2005, n. 217, e' sostituito dal seguente: «6. Nel caso in cui la Corte dei conti, in sede di esercizio del controllo preventivo di legittimita' sul decreto di cui al comma 5, richieda chiarimenti o elementi integrativi, ai sensi dell'articolo 3, comma 2, della legge 14 gennaio 1994, n. 20, le controdeduzioni devono essere trasmesse entro quindici giorni.».

7. All'articolo 20 del decreto legislativo 15 febbraio 2006, n. 63, il comma 3 e' sostituito dal seguente: «3. La disciplina emanata con il decreto di cui al comma 2 ha durata triennale tanto per la parte economica che normativa, a decorrere dal termine di scadenza previsto dal precedente decreto e conserva efficacia fino alla data di entrata in vigore del decreto successivo.».

### Art. 64. - Modifiche all'articolo 43 del decreto legislativo 30 marzo 2001, n. 165

1. All'articolo 43, comma 5, le parole: «40, comma 3» sono sostituite dalle seguenti: «40, commi 3-bis e seguenti».

### Art. 65. - Adeguamento ed efficacia dei contratti collettivi vigenti

1. Entro il 31 dicembre 2010, le parti adeguano i contratti collettivi integrativi vigenti alla data di entrata in vigore del presente decreto alle disposizioni riguardanti la definizione degli ambiti riservati, rispettivamente, alla contrattazione collettiva e alla legge, nonche' a quanto previsto dalle disposizioni del Titolo III del presente decreto. ((4))

2. In caso di mancato adeguamento ai sensi del comma 1, i contratti collettivi integrativi vigenti alla data di entrata in vigore del presente decreto cessano la loro efficacia dal 1° gennaio 2011 e non sono ulteriormente applicabili. ((4))

3. In via transitoria, con riferimento al periodo contrattuale immediatamente successivo a quello in corso, definiti i comparti e le aree di contrattazione ai sensi degli articoli 40, comma 2, e 41, comma 4, del decreto legislativo 30 marzo 2001, n. 165, come sostituiti, rispettivamente, dagli articoli 54 e 56 del presente decreto legislativo, l'ARAN avvia le trattative contrattuali con le organizzazioni sindacali e le confederazioni rappresentative. In deroga all'articolo 42, comma 4, del predetto decreto legislativo n. 165 del 2001, sono prorogati gli organismi di rappresentanza del personale anche se le relative elezioni siano state gia' indette. Le elezioni relative al rinnovo dei predetti organismi di rappresentanza si svolgeranno, con riferimento ai nuovi comparti di contrattazione, entro il 30 novembre 2010.

4. Relativamente al comparto regioni e autonomie locali, i termini di cui ai commi 1 e 2 sono fissati rispettivamente al 31 dicembre 2011 e al 31 dicembre 2012, fermo restando quanto previsto dall'((articolo 31, comma 4.)) ((4))

5. Le disposizioni relative alla contrattazione collettiva nazionale di cui al presente decreto legislativo si applicano dalla tornata successiva a quella in corso. ((4))

------------- AGGIORNAMENTO (4) Il D.Lgs. 1 agosto 2011, n. 141 ha disposto (con l'art. 5, comma 1) che "L'articolo 65, commi 1, 2 e 4, del decreto legislativo 27 ottobre 2009, n. 150, si interpreta nel senso che l'adeguamento dei contratti collettivi integrativi e' necessario solo per i contratti vigenti alla data di entrata in vigore del citato decreto legislativo, mentre ai contratti sottoscritti successivamente si applicano immediatamente le disposizioni introdotte dal medesimo decreto". Ha inoltre disposto (con l'art. 5, comma 2) che "L'articolo 65, comma 5, del decreto legislativo 27 ottobre 2009, n. 150, si interpreta nel senso che le disposizioni che si applicano dalla tornata contrattuale successiva a quella in corso al momento dell'entrata in vigore dello stesso decreto legislativo 27 ottobre 2009, n. 150, sono esclusivamente quelle relative al procedimento negoziale di approvazione dei contratti collettivi nazionali e, in particolare, quelle contenute negli articoli 41, commi da 1 a 4, 46, commi da 3 a 7, e 47 del decreto legislativo 30 marzo 2001, n. 165, come modificati rispettivamente dagli articoli 56, 58, 59, comma 1, del citato decreto legislativo n. 150 del 2009, nonche' quella dell'articolo 66, comma 3, del decreto legislativo n. 150 del 2009".

### Art. 66. - Abrogazioni

1. Sono abrogati:

- a) l'articolo 39, comma 3-ter, della legge 27 dicembre 1997, n. 449, e successive modificazioni;
- b) l'articolo 28, comma 2, del decreto legislativo 19 maggio 2000, n. 139;
- c) gli articoli 36, comma 2, e 82, comma 2, del decreto legislativo 13 ottobre 2005, n. 217;
- d) l'articolo 22, comma 2, del decreto legislativo 15 febbraio 2006, n. 63;
- e) l'articolo 67, commi da 7 a 12, del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133.

2. All'articolo 11, comma 8, del decreto del Presidente della Repubblica 4 dicembre 1997, n. 465, e successive modificazioni, le parole: «, sulla base delle direttive impartite dal Governo all'ARAN, sentite l'ANCI e l'UPI» sono soppresse. E' conseguentemente abrogato l'articolo 23 del decreto legislativo 29 ottobre 1998, n. 387.

3. All'articolo 70, comma 4, del decreto legislativo 30 marzo 2001, n. 165, il terzo, il quarto ed il quinto periodo sono soppressi. L'Ente nazionale aviazione civile (ENAC), l'Agenzia spaziale italiana - (ASI), il Centro nazionale per l'informatica per la pubblica amministrazione (CNIPA), l'UNIONCAMERE ed il Consiglio nazionale dell'economia e del lavoro (CNEL) sono ricollocati nell'ambito dei comparti e aree di contrattazione collettiva ai sensi dell'articolo 40, comma 2, del decreto legislativo n. 165 del 2001 e ad essi si applica interamente il Titolo III del medesimo decreto legislativo.

## Sanzioni disciplinari e responsabilita' dei dipendenti pubblici

### Art. 67. - Oggetto e finalita'

1. In attuazione dell'articolo 7 della legge 4 marzo 2009, n. 15, le disposizioni del presente Capo recano modifiche in materia di sanzioni disciplinari e responsabilita' dei dipendenti delle amministrazioni pubbliche in relazione ai rapporti di lavoro di cui all'articolo 2, comma 2, del decreto legislativo n. 165 del 2001, al fine di potenziare il livello di efficienza degli uffici pubblici e di contrastare i fenomeni di scarsa produttivita' ed assenteismo.

2. Resta ferma la devoluzione al giudice ordinario delle controversie relative al procedimento e alle sanzioni disciplinari, ai sensi dell'articolo 63 del decreto legislativo n. 165 del 2001.

### Art. 68. - Ambito di applicazione, codice disciplinare, procedure di conciliazione

1. L'articolo 55 del decreto legislativo 30 marzo 2001, n. 165, e' sostituito dal seguente: «Art. 55 (Responsabilita', infrazioni e sanzioni, procedure conciliative). - 1. Le disposizioni del presente articolo e di quelli seguenti, fino all'articolo 55-octies, costituiscono norme imperative, ai sensi e per gli effetti degli articoli 1339 e 1419, secondo comma, del codice civile, e si applicano ai rapporti di lavoro di cui all'articolo 2, comma 2, alle dipendenze delle amministrazioni pubbliche di cui all'articolo 1, comma 2. 2. Ferma la disciplina in materia di responsabilita' civile, amministrativa, penale e contabile, ai rapporti di lavoro di cui al comma 1 si applica l'articolo 2106 del codice civile. Salvo quanto previsto dalle disposizioni del presente Capo, la tipologia delle infrazioni e delle relative sanzioni e' definita dai contratti collettivi. La pubblicazione sul sito istituzionale dell'amministrazione del codice disciplinare, recante l'indicazione delle predette infrazioni e relative sanzioni, equivale a tutti gli effetti alla sua affissione all'ingresso della sede di lavoro. 3. La contrattazione collettiva non puo' istituire procedure di impugnazione dei provvedimenti disciplinari. Resta salva la facolta' di disciplinare mediante i contratti collettivi procedure di conciliazione non obbligatoria, fuori dei casi per i quali e' prevista la sanzione disciplinare del licenziamento, da instaurarsi e concludersi entro un termine non superiore a trenta giorni dalla contestazione dell'addebito e comunque prima dell'irrogazione della sanzione. La sanzione concordemente determinata all'esito di tali procedure non puo' essere di specie diversa da quella prevista, dalla legge o dal contratto collettivo, per l'infrazione per la quale si procede e non e' soggetta ad impugnazione. I termini del procedimento disciplinare restano sospesi dalla data di apertura della procedura conciliativa e riprendono a decorrere nel caso di conclusione con esito negativo. Il contratto collettivo definisce gli atti della procedura conciliativa che ne determinano l'inizio e la conclusione. 4. Fermo quanto previsto nell'articolo 21, per le infrazioni disciplinari ascrivibili al dirigente ai sensi degli articoli 55-bis, comma 7, e 55-sexies, comma 3, si applicano, ove non diversamente stabilito dal contratto collettivo, le disposizioni di cui al comma 4 del predetto articolo 55-bis, ma le determinazioni conclusive del procedimento sono adottate dal dirigente generale o titolare di incarico conferito ai sensi dell'articolo 19, comma 3.».

### Art. 69. - Disposizioni relative al procedimento disciplinare

1. Dopo l'articolo 55 del decreto legislativo n. 165 del 2001 sono inseriti i seguenti: «Art. 55-bis (Forme e termini del procedimento disciplinare). - 1. Per le infrazioni di minore gravita', per le quali e' prevista l'irrogazione di sanzioni superiori al rimprovero verbale ed inferiori alla sospensione dal servizio con privazione della retribuzione per piu' di dieci giorni, il procedimento disciplinare, se il responsabile della struttura ha qualifica dirigenziale, si svolge secondo le disposizioni del comma 2. Quando il responsabile della struttura non ha qualifica dirigenziale o comunque per le infrazioni punibili con sanzioni piu' gravi di quelle indicate nel primo periodo, il procedimento disciplinare si svolge secondo le disposizioni del comma 4. Alle infrazioni per le quali e' previsto il rimprovero verbale si applica la disciplina stabilita dal contratto collettivo. 2. Il responsabile, con qualifica dirigenziale, della struttura in cui il dipendente lavora, anche in posizione di comando o di fuori ruolo, quando ha notizia di comportamenti punibili con taluna delle sanzioni disciplinari di cui al comma 1, primo periodo, senza indugio e comunque non oltre venti giorni contesta per iscritto l'addebito al dipendente medesimo e lo convoca per il contraddittorio a sua difesa, con l'eventuale assistenza di un procuratore ovvero di un rappresentante dell'associazione sindacale cui il lavoratore aderisce o conferisce mandato, con un preavviso di almeno dieci giorni. Entro il termine fissato, il dipendente convocato, se non intende presentarsi, puo' inviare una memoria scritta o, in caso di grave ed oggettivo impedimento, formulare motivata istanza di rinvio del termine per l'esercizio della sua difesa. Dopo l'espletamento dell'eventuale ulteriore attivita' istruttoria, il responsabile della struttura conclude il procedimento, con l'atto di archiviazione o di irrogazione della sanzione, entro sessanta giorni dalla contestazione dell'addebito. In caso di differimento superiore a dieci giorni del termine a difesa, per impedimento del dipendente, il termine per la conclusione del procedimento e' prorogato in misura corrispondente. Il differimento puo' essere disposto per una sola volta nel corso del procedimento. La violazione dei termini stabiliti nel presente comma comporta, per l'amministrazione, la decadenza dall'azione disciplinare ovvero, per il dipendente, dall'esercizio del diritto di difesa. 3. Il responsabile della struttura, se non ha qualifica dirigenziale ovvero se la sanzione da applicare e' piu' grave di quelle di cui al comma 1, primo periodo, trasmette gli atti, entro cinque giorni dalla notizia del fatto, all'ufficio individuato ai sensi del comma 4, dandone contestuale comunicazione all'interessato. 4. Ciascuna amministrazione, secondo il proprio ordinamento, individua l'ufficio competente per i procedimenti disciplinari ai sensi del comma 1, secondo periodo. Il predetto ufficio contesta l'addebito al dipendente, lo convoca per il contraddittorio a sua difesa, istruisce e conclude il procedimento secondo quanto previsto nel comma 2, ma, se la sanzione da applicare e' piu' grave di quelle di cui al comma 1, primo periodo, con applicazione di termini pari al doppio di quelli ivi stabiliti e salva l'eventuale sospensione ai sensi dell'articolo 55-ter. Il termine per la contestazione dell'addebito decorre dalla data di ricezione degli atti trasmessi ai sensi del comma 3 ovvero dalla data nella quale l'ufficio ha altrimenti acquisito notizia dell'infrazione, mentre la decorrenza del termine per la conclusione del procedimento resta comunque fissata alla data di prima acquisizione della notizia dell'infrazione, anche se avvenuta da parte del responsabile della struttura in cui il dipendente lavora. La violazione dei termini di cui al presente comma comporta, per l'amministrazione, la decadenza dall'azione disciplinare ovvero, per il dipendente, dall'esercizio del diritto di difesa. 5. Ogni comunicazione al dipendente, nell'ambito del procedimento disciplinare, e' effettuata tramite posta elettronica certificata, nel caso in cui il dipendente dispone di idonea casella di posta, ovvero tramite consegna a mano. Per le comunicazioni successive alla contestazione dell'addebito, il dipendente puo' indicare, altresi', un numero di fax, di cui egli o il suo procuratore abbia la disponibilita'. In alternativa all'uso della posta elettronica certificata o del fax ed altresi' della consegna a mano, le comunicazioni sono effettuate tramite raccomandata postale con ricevuta di ritorno. Il dipendente ha diritto di accesso agli atti istruttori del procedimento. E' esclusa l'applicazione di termini diversi o ulteriori rispetto a quelli stabiliti nel presente articolo. 6. Nel corso dell'istruttoria, il capo della struttura o l'ufficio per i procedimenti disciplinari possono acquisire da altre amministrazioni pubbliche informazioni o documenti rilevanti per la definizione del procedimento. La predetta attivita' istruttoria non determina la sospensione del procedimento, ne' il differimento dei relativi termini. 7. Il lavoratore dipendente o il dirigente, appartenente alla stessa amministrazione pubblica dell'incolpato o ad una diversa, che, essendo a conoscenza per ragioni di ufficio o di servizio di informazioni rilevanti per un procedimento disciplinare in corso, rifiuta, senza giustificato motivo, la collaborazione richiesta dall'autorita' disciplinare procedente ovvero rende dichiarazioni false o reticenti, e' soggetto all'applicazione, da parte dell'amministrazione di appartenenza, della sanzione disciplinare della sospensione dal servizio con privazione della retribuzione, commisurata alla gravita' dell'illecito contestato al dipendente, fino ad un massimo di quindici giorni. 8. In caso di trasferimento del dipendente, a qualunque titolo, in un'altra amministrazione pubblica, il procedimento disciplinare e' avviato o concluso o la sanzione e' applicata presso quest'ultima. In tali casi i termini per la contestazione dell'addebito o per la conclusione del procedimento, se ancora pendenti, sono interrotti e riprendono a decorrere alla data del trasferimento. 9. In caso di dimissioni del dipendente, se per l'infrazione commessa e' prevista la sanzione del licenziamento o se comunque e' stata disposta la sospensione cautelare dal servizio, il procedimento disciplinare ha egualmente corso secondo le disposizioni del presente articolo e le determinazioni conclusive sono assunte ai fini degli effetti giuridici non preclusi dalla cessazione del rapporto di lavoro. Art. 55-ter (Rapporti fra procedimento disciplinare e procedimento penale). - 1. Il procedimento disciplinare, che abbia ad oggetto, in tutto o in parte, fatti in relazione ai quali procede l'autorita' giudiziaria, e' proseguito e concluso anche in pendenza del procedimento penale. Per le infrazioni di minore gravita', di cui all'articolo 55-bis, comma 1, primo periodo, non e' ammessa la sospensione del procedimento. Per le infrazioni di maggiore gravita', di cui all'articolo 55-bis, comma 1, secondo periodo, l'ufficio competente, nei casi di particolare complessita' dell'accertamento del fatto addebitato al dipendente e quando all'esito dell'istruttoria non dispone di elementi sufficienti a motivare l'irrogazione della sanzione, puo' sospendere il procedimento disciplinare fino al termine di quello penale, salva la possibilita' di adottare la sospensione o altri strumenti cautelari nei confronti del dipendente. 2. Se il procedimento disciplinare, non sospeso, si conclude con l'irrogazione di una sanzione e, successivamente, il procedimento penale viene definito con una sentenza irrevocabile di assoluzione che riconosce che il fatto addebitato al dipendente non sussiste o non costituisce illecito penale o che il dipendente medesimo non lo ha commesso, l'autorita' competente, ad istanza di parte da proporsi entro il termine di decadenza di sei mesi dall'irrevocabilita' della pronuncia penale, riapre il procedimento disciplinare per modificarne o confermarne l'atto conclusivo in relazione all'esito del giudizio penale. 3. Se il procedimento disciplinare si conclude con l'archiviazione ed il processo penale con una sentenza irrevocabile di condanna, l'autorita' competente riapre il procedimento disciplinare per adeguare le determinazioni conclusive all'esito del giudizio penale. Il procedimento disciplinare e' riaperto, altresi', se dalla sentenza irrevocabile di condanna risulta che il fatto addebitabile al dipendente in sede disciplinare comporta la sanzione del licenziamento, mentre ne e' stata applicata una diversa. 4. Nei casi di cui ai commi 1, 2 e 3 il procedimento disciplinare e', rispettivamente, ripreso o riaperto entro sessanta giorni dalla comunicazione della sentenza all'amministrazione di appartenenza del lavoratore ovvero dalla presentazione dell'istanza di riapertura ed e' concluso entro centottanta giorni dalla ripresa o dalla riapertura. La ripresa o la riapertura avvengono mediante il rinnovo della contestazione dell'addebito da parte dell'autorita' disciplinare competente ed il procedimento prosegue secondo quanto previsto nell'articolo 55-bis. Ai fini delle determinazioni conclusive, l'autorita' procedente, nel procedimento disciplinare ripreso o riaperto, applica le disposizioni dell'articolo 653, commi 1 ed 1-bis, del codice di procedura penale. Art. 55-quater (Licenziamento disciplinare). - 1. Ferma la disciplina in tema di licenziamento per giusta causa o per giustificato motivo e salve ulteriori ipotesi previste dal contratto collettivo, si applica comunque la sanzione disciplinare del licenziamento nei seguenti casi: a) falsa attestazione della presenza in servizio, mediante l'alterazione dei sistemi di rilevamento della presenza o con altre modalita' fraudolente, ovvero giustificazione dell'assenza dal servizio mediante una certificazione medica falsa o che attesta falsamente uno stato di malattia; b) assenza priva di valida giustificazione per un numero di giorni, anche non continuativi, superiore a tre nell'arco di un biennio o comunque per piu' di sette giorni nel corso degli ultimi dieci anni ovvero mancata ripresa del servizio, in caso di assenza ingiustificata, entro il termine fissato dall'amministrazione; c) ingiustificato rifiuto del trasferimento disposto dall'amministrazione per motivate esigenze di servizio; d) falsita' documentali o dichiarative commesse ai fini o in occasione dell'instaurazione del rapporto di lavoro ovvero di progressioni di carriera; e) reiterazione nell'ambiente di lavoro di gravi condotte aggressive o moleste o minacciose o ingiuriose o comunque lesive dell'onore e della dignita' personale altrui; f) condanna penale definitiva, in relazione alla quale e' prevista l'interdizione perpetua dai pubblici uffici ovvero l'estinzione, comunque denominata, del rapporto di lavoro. 2. Il licenziamento in sede disciplinare e' disposto, altresi', nel caso di prestazione lavorativa, riferibile ad un arco temporale non inferiore al biennio, per la quale l'amministrazione di appartenenza formula, ai sensi delle disposizioni legislative e contrattuali concernenti la valutazione del personale delle amministrazioni pubbliche, una valutazione di insufficiente rendimento e questo e' dovuto alla reiterata violazione degli obblighi concernenti la prestazione stessa, stabiliti da norme legislative o regolamentari, dal contratto collettivo o individuale, da atti e provvedimenti dell'amministrazione di appartenenza o dai codici di comportamento di cui all'articolo 54. 3. Nei casi di cui al comma 1, lettere a), d), e) ed f), il licenziamento e' senza preavviso. Art. 55-quinquies (False attestazioni o certificazioni). - 1. Fermo quanto previsto dal codice penale, il lavoratore dipendente di una pubblica amministrazione che attesta falsamente la propria presenza in servizio, mediante l'alterazione dei sistemi di rilevamento della presenza o con altre modalita' fraudolente, ovvero giustifica l'assenza dal servizio mediante una certificazione medica falsa o falsamente attestante uno stato di malattia e' punito con la reclusione da uno a cinque anni e con la multa da euro 400 ad euro 1.600. La medesima pena si applica al medico e a chiunque altro concorre nella commissione del delitto. 2. Nei casi di cui al comma 1, il lavoratore, ferme la responsabilita' penale e disciplinare e le relative sanzioni, e' obbligato a risarcire il danno patrimoniale, pari al compenso corrisposto a titolo di retribuzione nei periodi per i quali sia accertata la mancata prestazione, nonche' il danno all'immagine subiti dall'amministrazione. 3. La sentenza definitiva di condanna o di applicazione della pena per il delitto di cui al comma 1 comporta, per il medico, la sanzione disciplinare della radiazione dall'albo ed altresi', se dipendente di una struttura sanitaria pubblica o se convenzionato con il servizio sanitario nazionale, il licenziamento per giusta causa o la decadenza dalla convenzione. Le medesime sanzioni disciplinari si applicano se il medico, in relazione all'assenza dal servizio, rilascia certificazioni che attestano dati clinici non direttamente constatati ne' oggettivamente documentati. Art. 55-sexies (Responsabilita' disciplinare per condotte pregiudizievoli per l'amministrazione e limitazione della responsabilita' per l'esercizio dell'azione disciplinare). - 1. La condanna della pubblica amministrazione al risarcimento del danno derivante dalla violazione, da parte del lavoratore dipendente, degli obblighi concernenti la prestazione lavorativa, stabiliti da norme legislative o regolamentari, dal contratto collettivo o individuale, da atti e provvedimenti dell'amministrazione di appartenenza o dai codici di comportamento di cui all'articolo 54, comporta l'applicazione nei suoi confronti, ove gia' non ricorrano i presupposti per l'applicazione di un'altra sanzione disciplinare, della sospensione dal servizio con privazione della retribuzione da un minimo di tre giorni fino ad un massimo di tre mesi, in proporzione all'entita' del risarcimento. 2. Fuori dei casi previsti nel comma 1, il lavoratore, quando cagiona grave danno al normale funzionamento dell'ufficio di appartenenza, per inefficienza o incompetenza professionale accertate dall'amministrazione ai sensi delle disposizioni legislative e contrattuali concernenti la valutazione del personale delle amministrazioni pubbliche, e' collocato in disponibilita', all'esito del procedimento disciplinare che accerta tale responsabilita', e si applicano nei suoi confronti le disposizioni di cui all'articolo 33, comma 8, e all'articolo 34, commi 1, 2, 3 e 4. Il provvedimento che definisce il giudizio disciplinare stabilisce le mansioni e la qualifica per le quali puo' avvenire l'eventuale ricollocamento. Durante il periodo nel quale e' collocato in disponibilita', il lavoratore non ha diritto di percepire aumenti retributivi sopravvenuti. 3. Il mancato esercizio o la decadenza dell'azione disciplinare, dovuti all'omissione o al ritardo, senza giustificato motivo, degli atti del procedimento disciplinare o a valutazioni sull'insussistenza dell'illecito disciplinare irragionevoli o manifestamente infondate, in relazione a condotte aventi oggettiva e palese rilevanza disciplinare, comporta, per i soggetti responsabili aventi qualifica dirigenziale, l'applicazione della sanzione disciplinare della sospensione dal servizio con privazione della retribuzione in proporzione alla gravita' dell'infrazione non perseguita, fino ad un massimo di tre mesi in relazione alle infrazioni sanzionabili con il licenziamento, ed altresi' la mancata attribuzione della retribuzione di risultato per un importo pari a quello spettante per il doppio del periodo della durata della sospensione. Ai soggetti non aventi qualifica dirigenziale si applica la predetta sanzione della sospensione dal servizio con privazione della retribuzione, ove non diversamente stabilito dal contratto collettivo. 4. La responsabilita' civile eventualmente configurabile a carico del dirigente in relazione a profili di illiceita' nelle determinazioni concernenti lo svolgimento del procedimento disciplinare e' limitata, in conformita' ai principi generali, ai casi di dolo o colpa grave. Art. 55-septies (Controlli sulle assenze). - 1. Nell'ipotesi di assenza per malattia protratta per un periodo superiore a dieci giorni, e, in ogni caso, dopo il secondo evento di malattia nell'anno solare l'assenza viene giustificata esclusivamente mediante certificazione medica rilasciata da una struttura sanitaria pubblica o da un medico convenzionato con il Servizio sanitario nazionale. 2. In tutti i casi di assenza per malattia la certificazione medica e' inviata per via telematica, direttamente dal medico o dalla struttura sanitaria che la rilascia, all'Istituto nazionale della previdenza sociale, secondo le modalita' stabilite per la trasmissione telematica dei certificati medici nel settore privato dalla normativa vigente, e in particolare dal decreto del Presidente del Consiglio dei Ministri previsto dall'articolo 50, comma 5-bis, del decreto-legge 30 settembre 2003, n. 269, convertito, con modificazioni, dalla legge 24 novembre 2003, n. 326, introdotto dall'articolo 1, comma 810, della legge 27 dicembre 2006, n. 296, e dal predetto Istituto e' immediatamente inoltrata, con le medesime modalita', all'amministrazione interessata. 3. L'Istituto nazionale della previdenza sociale, gli enti del servizio sanitario nazionale e le altre amministrazioni interessate svolgono le attivita' di cui al comma 2 con le risorse finanziarie, strumentali e umane disponibili a legislazione vigente, senza nuovi o maggiori oneri a carico della finanza pubblica. 4. L'inosservanza degli obblighi di trasmissione per via telematica della certificazione medica concernente assenze di lavoratori per malattia di cui al comma 2 costituisce illecito disciplinare e, in caso di reiterazione, comporta l'applicazione della sanzione del licenziamento ovvero, per i medici in rapporto convenzionale con le aziende sanitarie locali, della decadenza dalla convenzione, in modo inderogabile dai contratti o accordi collettivi. 5. L'Amministrazione dispone il controllo in ordine alla sussistenza della malattia del dipendente anche nel caso di assenza di un solo giorno, tenuto conto delle esigenze funzionali e organizzative. Le fasce orarie di reperibilita' del lavoratore, entro le quali devono essere effettuate le visite mediche di controllo, sono stabilite con decreto del Ministro per la pubblica amministrazione e l'innovazione. 6. Il responsabile della struttura in cui il dipendente lavora nonche' il dirigente eventualmente preposto all'amministrazione generale del personale, secondo le rispettive competenze, curano l'osservanza delle disposizioni del presente articolo, in particolare al fine di prevenire o contrastare, nell'interesse della funzionalita' dell'ufficio, le condotte assenteistiche. Si applicano, al riguardo, le disposizioni degli articoli 21 e 55-sexies, comma 3. Art. 55-octies (Permanente inidoneita' psicofisica). - 1. Nel caso di accertata permanente inidoneita' psicofisica al servizio dei dipendenti delle amministrazioni pubbliche, di cui all'articolo 2, comma 2, l'amministrazione puo' risolvere il rapporto di lavoro. Con regolamento da emanarsi, ai sensi dell'articolo 17, comma 1, lettera b), della legge 23 agosto 1988, n. 400, sono disciplinati, per il personale delle amministrazioni statali, anche ad ordinamento autonomo, nonche' degli enti pubblici non economici: a) la procedura da adottare per la verifica dell'idoneita' al servizio, anche ad iniziativa dell'Amministrazione; b) la possibilita' per l'amministrazione, nei casi di pericolo per l'incolumita' del dipendente interessato nonche' per la sicurezza degli altri dipendenti e degli utenti, di adottare provvedimenti di sospensione cautelare dal servizio, in attesa dell'effettuazione della visita di idoneita', nonche' nel caso di mancata presentazione del dipendente alla visita di idoneita', in assenza di giustificato motivo; c) gli effetti sul trattamento giuridico ed economico della sospensione di cui alla lettera b), nonche' il contenuto e gli effetti dei provvedimenti definitivi adottati dall'amministrazione in seguito all'effettuazione della visita di idoneita'; d) la possibilita', per l'amministrazione, di risolvere il rapporto di lavoro nel caso di reiterato rifiuto, da parte del dipendente, di sottoporsi alla visita di idoneita'. Art. 55-novies (Identificazione del personale a contatto con il pubblico). - 1. I dipendenti delle amministrazioni pubbliche che svolgono attivita' a contatto con il pubblico sono tenuti a rendere conoscibile il proprio nominativo mediante l'uso di cartellini identificativi o di targhe da apporre presso la postazione di lavoro. 2. Dall'obbligo di cui al comma 1 e' escluso il personale individuato da ciascuna amministrazione sulla base di categorie determinate, in relazione ai compiti ad esse attribuiti, mediante uno o piu' decreti del Presidente del Consiglio dei Ministri o del Ministro per la pubblica amministrazione e l'innovazione, su proposta del Ministro competente ovvero, in relazione al personale delle amministrazioni pubbliche non statali, previa intesa in sede di Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano o di Conferenza Stato-citta' ed autonomie locali.».

### Art. 70. - Comunicazione della sentenza

1. Dopo l'articolo 154-bis del decreto legislativo 28 luglio 1989, n. 271, e' inserito il seguente: «Art. 154-ter (Comunicazione della sentenza). - 1. La cancelleria del giudice che ha pronunciato sentenza penale nei confronti di un lavoratore dipendente di un'amministrazione pubblica ne comunica il dispositivo all'amministrazione di appartenenza e, su richiesta di questa, trasmette copia integrale del provvedimento. La comunicazione e la trasmissione sono effettuate con modalita' telematiche, ai sensi del decreto legislativo 7 marzo 2005, n. 82, entro trenta giorni dalla data del deposito.».

### Art. 71. - Ampliamento dei poteri ispettivi

1. All'articolo 60 del decreto legislativo n. 165 del 2001, il comma 6 e' sostituito dal seguente: «6. Presso la Presidenza del Consiglio dei Ministri - Dipartimento della funzione pubblica e' istituito l'Ispettorato per la funzione pubblica, che opera alle dirette dipendenze del Ministro delegato. L'Ispettorato vigila e svolge verifiche sulla conformita' dell'azione amministrativa ai principi di imparzialita' e buon andamento, sull'efficacia della sua attivita' con particolare riferimento alle riforme volte alla semplificazione delle procedure, sul corretto conferimento degli incarichi, sull'esercizio dei poteri disciplinari, sull'osservanza delle disposizioni vigenti in materia di controllo dei costi, dei rendimenti, dei risultati, di verifica dei carichi di lavoro. Collabora alle verifiche ispettive di cui al comma 5. Nell'ambito delle proprie verifiche, l'Ispettorato puo' avvalersi della Guardia di Finanza che opera nell'esercizio dei poteri ad essa attribuiti dalle leggi vigenti. Per le predette finalita' l'Ispettorato si avvale altresi' di un numero complessivo di dieci funzionari scelti tra esperti del Ministero dell'economia e delle finanze, del Ministero dell'interno, o comunque tra il personale di altre amministrazioni pubbliche, in posizione di comando o fuori ruolo, per il quale si applicano l'articolo 17, comma 14, della legge 15 maggio 1997, n. 127, e l'articolo 56, comma 7, del Testo unico delle disposizioni concernenti lo statuto degli impiegati civili dello Stato di cui al decreto del Presidente della Repubblica 10 gennaio 1957, n. 3, e successive modificazioni. Per l'esercizio delle funzioni ispettive connesse, in particolare, al corretto conferimento degli incarichi e ai rapporti di collaborazione, svolte anche d'intesa con il Ministero dell'economia e delle finanze, l'Ispettorato si avvale dei dati comunicati dalle amministrazioni al Dipartimento della funzione pubblica ai sensi dell'articolo 53. L'Ispettorato, inoltre, al fine di corrispondere a segnalazioni da parte di cittadini o pubblici dipendenti circa presunte irregolarita', ritardi o inadempienze delle amministrazioni di cui all'articolo 1, comma 2, puo' richiedere chiarimenti e riscontri in relazione ai quali l'amministrazione interessata ha l'obbligo di rispondere, anche per via telematica, entro quindici giorni. A conclusione degli accertamenti, gli esiti delle verifiche svolte dall'ispettorato costituiscono obbligo di valutazione, ai fini dell'individuazione delle responsabilita' e delle eventuali sanzioni disciplinari di cui all'articolo 55, per l'amministrazione medesima. Gli ispettori, nell'esercizio delle loro funzioni, hanno piena autonomia funzionale ed hanno l'obbligo, ove ne ricorrano le condizioni, di denunciare alla Procura generale della Corte dei conti le irregolarita' riscontrate.».

### Art. 72. - Abrogazioni

1. Sono abrogate le seguenti disposizioni:

- a) articolo 71, commi 2 e 3, del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133;
- b) articoli da 502 a 507 del decreto legislativo 16 aprile 1994, n. 297;
- c) l'articolo 56 del decreto legislativo 30 marzo 2001, n. 165.

2. All'articolo 5, comma 4, della legge 27 marzo 2001, n. 97, le parole: «, salvi termini diversi previsti dai contratti collettivi nazionali di lavoro,» sono soppresse.

### Art. 73. - Norme transitorie

1. Dalla data di entrata in vigore del presente decreto non e' ammessa, a pena di nullita', l'impugnazione di sanzioni disciplinari dinanzi ai collegi arbitrali di disciplina. I procedimenti di impugnazione di sanzioni disciplinari pendenti dinanzi ai predetti collegi alla data di entrata in vigore del presente decreto sono definiti, a pena di nullita' degli atti, entro il termine di sessanta giorni decorrente dalla predetta data.

2. L'obbligo di esposizione di cartellini o targhe identificativi, previsto dall'articolo 55-novies del decreto legislativo 30 marzo 2001, n. 165, introdotto dall'articolo 69 del presente decreto, decorre dal novantesimo giorno successivo all'entrata in vigore del presente decreto.

3. Le disposizioni di legge, non incompatibili con quelle del presente decreto, concernenti singole amministrazioni e recanti fattispecie sanzionatorie specificamente concernenti i rapporti di lavoro del personale di cui all'articolo 2, comma 2, del decreto legislativo 30 marzo 2001, n. 165, continuano ad essere applicabili fino al primo rinnovo del contratto collettivo di settore successivo alla data di entrata in vigore del presente decreto.

## NORME FINALI E TRANSITORIE

### Art. 74. - Ambito di applicazione

1. Gli articoli 11, commi 1 e 3, da 28 a 30, da 33 a 36, 54, 57, 61, 62, comma 1, 64, 65, 66, 68, 69 e 73, commi 1 e 3, rientrano nella potesta' legislativa esclusiva esercitata dallo Stato, ai sensi dell'articolo 117, secondo comma, letterel) edm), della Costituzione.

2. Gli articoli 3, 4, 5, comma 2, 7, 9, 15, comma 1, 17, comma 2, 18, 23, commi 1 e 2, 24, commi 1 e 2, 25, 26, 27, comma 1, e l'articolo 62, commi 1-bis e 1-ter recano norme di diretta attuazione dell'articolo 97 della Costituzione e costituiscono principi generali dell'ordinamento ai quali si adeguano le regioni e gli enti locali, anche con riferimento agli enti del Servizio sanitario nazionale, negli ambiti di rispettiva competenza.

3. Con uno o piu' decreti del Presidente del Consiglio dei Ministri sono determinati, in attuazione dell'articolo 2, comma 5, della legge 4 marzo 2009, n.15, limiti e modalita' di applicazione delle disposizioni, anche inderogabili, del presente decreto alla Presidenza del Consiglio dei Ministri, anche con riferimento alla definizione del comparto autonomo di contrattazione collettiva, in considerazione della peculiarita' del relativo ordinamento, che discende dagli articoli 92 e 95 della Costituzione. Fino alla data di entrata in vigore di ciascuno di tali decreti, alla Presidenza del Consiglio dei Ministri continua ad applicarsi la normativa previgente.

4. Con decreto del Presidente del Consiglio dei Ministri, di concerto con il Ministro dell'istruzione, dell'universita' e della ricerca e con il Ministro dell'economia e delle finanze, sono determinati i limiti e le modalita' di applicazione delle diposizioni dei Titoli II e III del presente decreto al personale docente della scuola e delle istituzioni di alta formazione artistica e musicale, nonche' ai tecnologi e ai ricercatori degli enti di ricerca. Resta comunque esclusa la costituzione degli Organismi di cui all'articolo 14 nell'ambito del sistema scolastico e delle istituzioni di alta formazione artistica e musicale.

5. Le disposizioni del presente decreto legislativo si applicano nei confronti delle regioni a statuto speciale e delle province autonome di Trento e di Bolzano compatibilmente con le attribuzioni previste dagli statuti e dalle relative norme di attuazione.

